{"name":"Nessus API Documentation","description":"This API documentation is organized by resource type. Each resource type has one or more data representations and one or more methods.","version":"10.7.2","permissions":{"user":{"permissions":{"16":{"name":"basic","description":"Users with this role can view and configure scan results."},"32":{"name":"standard","description":"Users with this role can create scans, policies, and user target groups."},"64":{"name":"administrator","description":"Users with this role have the same privileges as the standard user but can also manage users, groups, agents and scanners."},"128":{"name":"system administrator","description":"Users with this role have full access."}}},"scan":{"manager":"true","permissions":{"0":{"name":"no access","description":"Scans with these permissions can not be viewed."},"16":{"name":"can view","description":"Scans with these permissions can be viewed."},"32":{"name":"can control","description":"Scans with these permissions can be controlled."},"64":{"name":"can configure","description":"Scans with these permissions can be configured."}}},"policy":{"manager":"true","permissions":{"0":{"name":"no access","description":"Policies with these permissions can not be used."},"16":{"name":"can use","description":"Policies with these permissions can be used."},"32":{"name":"can edit","description":"Policies with these permissions can be edited."}}},"scanner":{"manager":"true","permissions":{"0":{"name":"no access","description":"Scanners with these permissions can not be used."},"16":{"name":"can use","description":"Scanners with these permissions can be used."},"64":{"name":"can manage","description":"Scanners with these permissions can be managed."}}},"agent":{"manager":"true","permissions":{"0":{"name":"no access","description":"Agent groups with these permissions can not be used."},"16":{"name":"can use","description":"Agent groups with these permissions can be used."}}}},"resources":{"agent-groups":{"name":"agent-groups","description":"","manager_only":true,"representations":[{"name":"group","description":"The details of an agent group.","parameters":{"id":{"type":"integer","description":"The unique id of the agent group."},"name":{"type":"string","description":"The name of the agent group."},"owner_id":{"type":"string","description":"The unique id of the owner of the agent group."},"owner":{"type":"string","description":"The username for the owner of the agent group."},"shared":{"type":"integer","description":"The shared status of the agent group."},"user_permissions":{"type":"integer","description":"The sharing permissions for the agent group."},"creation_date":{"type":"integer","description":"The creation date of the agent group in unixtime."},"last_modification_date":{"type":"integer","description":"The last modification date for the agent group in unixtime."}}}],"methods":{"add-agent":{"description":"Add an agent to the given agent group.","method":"PUT","uri":"agent-groups/{group_id}/agents/{agent_id}","request":{"description":"","parameters":{"path":{"group_id":{"type":"integer","description":"The id of the agent group.","required":true},"agent_id":{"type":"integer","description":"The id of the agent to add.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agent was added to the group."},"404":{"description":"Returned if the agent group does not exist."},"500":{"description":"Returned if an error occurred while attempting to add the agent."}}}},"add-agents":{"description":"Add multiple agents to the given agent group.","method":"PUT","uri":"agent-groups/{group_id}/agents","request":{"description":"","parameters":{"path":{"group_id":{"type":"integer","description":"The id of the agent group.","required":true}},"payload":{"ids":{"type":"array","description":"Array of agent IDs to add.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agents were added to the group."},"400":{"description":"Returned if any of the agent IDs are invalid."},"500":{"description":"Returned if an error occurred while attempting to add the agents."}}}},"configure":{"description":"Changes the name of the given agent group.","method":"PUT","uri":"agent-groups/{group_id}","request":{"description":"","parameters":{"path":{"group_id":{"type":"integer","description":"The id of the agent group to change.","required":true}},"payload":{"name":{"type":"string","description":"The name for the agent group.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the configuration was changed."},"404":{"description":"Returned if the agent group does not exist."},"500":{"description":"Returned if an error occurred while saving the configuration."}}}},"create":{"description":"Create an agent group.","method":"POST","uri":"agent-groups","request":{"parameters":{"payload":{"name":{"type":"string","description":"The name of the agent group.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agent group has been created."},"400":{"description":"Returned if a field is invalid."},"403":{"description":"Returned if the user does not have permission to create an agent group."},"500":{"description":"Returned if the server failed to add the agent group."}},"sample":{"data":"representation: agent-groups.group"}}},"delete-group":{"description":"Delete an agent group.","method":"DELETE","uri":"agent-groups/{group_id}","request":{"parameters":{"path":{"group_id":{"type":"integer","description":"The id of the agent group to delete.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agent group has been successfully deleted."},"404":{"description":"Returned if the agent group does not exist."},"500":{"description":"Returned if the server failed to delete the agent group."}}}},"delete-groups":{"description":"Delete multiple agent groups.","method":"DELETE","uri":"agent-groups","request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of agent group IDs to delete.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agent groups have been successfully deleted."},"500":{"description":"Returned if the server failed to delete all the agent groups."}}}},"delete-agent":{"description":"Delete an agent from the given agent group.","method":"DELETE","uri":"agent-groups/{group_id}/agents/{agent_id}","request":{"parameters":{"path":{"group_id":{"type":"integer","description":"The id of the agent group.","required":true},"agent_id":{"type":"integer","description":"The id of the agent to remove.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agent has been successfully removed from the agent group."},"404":{"description":"Returned if the agent does not exist."},"500":{"description":"Returned if the server failed to remove the agent from the agent group."}}}},"delete-agents":{"description":"Delete multiple agents from the given agent group.","method":"DELETE","uri":"agent-groups/{group_id}/agents","request":{"description":"","parameters":{"path":{"group_id":{"type":"integer","description":"The id of the agent group.","required":true}},"payload":{"ids":{"type":"array","description":"Array of agent IDs to delete.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agents were deleted from the group."},"400":{"description":"Returned if any of the agent IDs are invalid."},"500":{"description":"Returned if an error occurred while attempting to delete the agents."}}}},"details":{"description":"Return details for the given agent group.","method":"GET","uri":"agent-groups/{group_id}","request":{"description":"","parameters":{"path":{"group_id":{"type":"integer","description":"The id of the agent group to query.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the agent group details."},"403":{"description":"Returned if user does not have permission to view the agent group."},"404":{"description":"Returned if the agent group does not exist."}},"sample":{"data":"representation: agent-groups.group"}}},"list":{"description":"Returns a list of agent groups.","method":"GET","uri":"agent-groups","request":{"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the agent groups list."},"403":{"description":"Returned if the user does not have permission to view the list."}},"sample":{"data":{"groups":["representation: agent-groups.group"]}}}}}},"agents":{"name":"agents","description":"","manager_only":true,"representations":[{"name":"agent","description":"The details of an agent connected to a scanner.","parameters":{"core_version":{"type":"string","description":"The agent software version."},"distro":{"type":"string","description":"The agent software distribution."},"groups":{"type":"array","description":"The groups of which the agent is a member."},"id":{"type":"integer","description":"The unique id of the agent."},"ip":{"type":"string","description":"The IP address of the agent."},"last_connect":{"type":"integer","description":"The date the agent last connected to Nessus Manager, in unixtime."},"last_scanned":{"type":"integer","description":"The last scanned date for the agent, in unixtime."},"linked_on":{"type":"integer","description":"The date the agent was linked, in unixtime."},"name":{"type":"string","description":"The name of the agent."},"mac_addrs":{"type":"string","description":"The MAC addresses of the agent's network interface(s)."},"platform":{"type":"string","description":"The platform of the agent."},"plugin_feed_id":{"type":"string","description":"The date ID of the agent's plugin set, in YYYYMMDDhhmm format."},"status":{"type":"string","description":"Nessus Manager's notion of the agent's state.  Possible values are 'unlinked', 'offline', 'online', and 'initializing'."},"unlinked_on":{"type":"integer","description":"The date the agent was unlinked, in unixtime."},"uuid":{"type":"string","description":"The uuid of the agent."}}}],"methods":{"delete":{"description":"Delete an agent.","method":"DELETE","uri":"agents/{agent_id}","request":{"parameters":{"path":{"agent_id":{"type":"integer","description":"The id of the agent to delete.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agent has been successfully deleted."},"404":{"description":"Returned if the agent does not exist."},"500":{"description":"Returned if the server failed to delete the agent."}}}},"delete-bulk":{"description":"Delete agents in bulk.","method":"DELETE","uri":"agents","request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of agent IDs to delete.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agents have been successfully deleted."},"400":{"description":"Returned if any of the agent IDs are invalid."},"500":{"description":"Returned if the server failed to delete the agents."}}}},"unlink":{"description":"Unlink an agent.  Only works if the Track Unlinked Agents feature is enabled.","method":"DELETE","uri":"agents/{agent_id}/unlink","request":{"parameters":{"path":{"agent_id":{"type":"integer","description":"The id of the agent to unlink.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agent has been successfully unlinked."},"404":{"description":"Returned if the agent does not exist."},"500":{"description":"Returned if the server failed to unlink the agent."}}}},"unlink-bulk":{"description":"Unlink agents in bulk.  Only works if the Track Unlinked Agents feature is enabled.","method":"DELETE","uri":"agents/unlink","request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of agent IDs to unlink.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agents have been successfully unlinked."},"400":{"description":"Returned if any of the agent IDs are invalid."},"500":{"description":"Returned if the server failed to unlink the agents."}}}},"list":{"description":"Returns list of agents.","method":"GET","uri":"agents","request":{"parameters":{"query":{"limit":{"type":"integer","description":"(global) The number agents that the server should return.","required":false},"offset":{"type":"integer","description":"(global) Request the next <b>limit</b> number of agents starting at this offset.","required":false},"sort_by":{"type":"string","description":"(global) Sort by <b>name</b>, <b>status</b>, <b>ip</b>, <b>platform</b>, <b>core_version</b>, <b>distro</b>, <b>last_connect</b>, or <b>last_scanned</b>.","required":false},"sort_order":{"type":"string","description":"(global) Sort order can be <b>asc</b> (ascending) or <b>desc</b> (descending).","required":false},"filter.search_type":{"type":"string","description":"(global) Search type can be <b>and</b> (match all) or <b>or</b> (match any).","required":false,"testable":false},"filter.FILTER_NUMBER.filter":{"type":"string","description":"(required for each FILTER_NUMBER) This can be <b>node_id</b> (exact), <b>ip</b>, (exact or partial) <b>last_connect</b> (date), <b>plugin_feed_id</b> (date), <b>last_scanned</b> (date), <b>groups</b> (exact), <b>name</b> (exact or partial), <b>platform</b> (partial), <b>distro</b> (partial), <b>status</b> (exact), or <b>core_version</b> (exact or partial).","required":false,"test_name":"filter.0.filter"},"filter.FILTER_NUMBER.quality":{"type":"string","description":"(required for each FILTER_NUMBER) This is one of <b>eq</b> or <b>neq</b> (exact); <b>match</b> or <b>nmatch</b> (partial); <b>date-eq</b>, <b>date-neq</b>, <b>date-lt</b>, or <b>date-gt</b> (exact).","required":false,"test_name":"filter.0.quality"},"filter.FILTER_NUMBER.value":{"type":"string","description":"(required for each FILTER_NUMBER) This is free-form text appropriate for each type, with the exception of <b>node_id</b> being an integer, dates formatted as YYYY-MM-DD, and groups represented by the name of the Agent group.","required":false,"test_name":"filter.0.value"}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the agent list."},"403":{"description":"Returned if the user does not have permission to view the list."}},"sample":{"data":{"agents":["representation: agents.agent"]}}}},"list-one":{"description":"List an agent.","method":"GET","uri":"agents/{agent_id}","request":{"parameters":{"path":{"agent_id":{"type":"integer","description":"The id of the agent to list.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the agent has been successfully found and listed."},"404":{"description":"Returned if the agent does not exist."}},"sample":{"data":{"agents":["representation: agents.agent"]}}}}}},"editor":{"name":"editor","description":"","representations":[{"name":"template","description":"Templates are used to create scans or policies with predefined parameters.","parameters":{"uuid":{"type":"string","description":"The uuid for the template."},"name":{"type":"string","description":"The short name of the template."},"title":{"type":"string","description":"The long name of the template."},"description":{"type":"string","description":"The description of the template."},"cloud_only":{"type":"boolean","description":"If true, template is only available on the cloud."},"subscription_only":{"type":"boolean","description":"If true, the template is only available for subscribers."},"is_agent":{"type":"boolean","description":"If true, the template is for agent scans."},"more_info":{"type":"string","description":"An external URL to link the template to."}}},{"name":"input","description":"A form input.","parameters":{"id":{"type":"string","description":"The unique id name for the group."},"type":{"type":"string","description":"The type of input (entry, checkbox, file, radio)."},"label":{"type":"string","description":"The label for the input."},"default":{"type":"string","description":"The default value for the input."},"options":{"type":"array","description":"The options for radio input."}}},{"name":"group","description":"A template display group.","parameters":{"name":{"type":"string","description":"The unique shortname for the group."},"title":{"type":"string","description":"The display name for the group."},"inputs":{"type":"array","description":"The default inputs for the group."},"sections":{"type":"array","description":"Subsections of inputs not categorized as default."}}},{"name":"section","description":"A section of inputs that are enabled/disabled as a group.","parameters":{"name":{"type":"string","description":"The unique shortname for the section."},"title":{"type":"string","description":"The display name for the section."},"inputs":{"type":"array","description":"The inputs for the section."}}},{"name":"mode","description":"A predefined group of settings.","parameters":{"id":{"type":"string","description":"The unique shortname for the mode."},"name":{"type":"string","description":"The display name for the mode."},"desc":{"type":"string","description":"The description for the mode (HTML)."}}},{"name":"family","description":"A family of plugins.","parameters":{"id":{"type":"integer","description":"The unique id for the family."},"count":{"type":"integer","description":"The number of plugins in the family."},"status":{"type":"string","description":"The status of the family (enabled, disabled, or mixed)."}}},{"name":"filter","description":"Filter used to search and sort plugins.","parameters":{"name":{"type":"string","description":"The short name of the filter."},"readable_name":{"type":"string","description":"The long name of the filter."},"operators":{"type":"array","description":"The comparison options for the filter."},"control":{"type":"object","description":"The input type, placeholder, and regex values for the filter.","parameters":{"type":{"type":"string","description":"The input type (entry or dropdown)."},"readable_regest":{"type":"string","description":"The placeholder for the input."},"regex":{"type":"string","description":"A regex for checking the value of the input."},"options":{"type":"array","description":"A list of options if the input is a dropdown."}}}}}],"methods":{"audits":{"description":"Export the given audit file.","method":"DOWNLOAD","uri":"editor/{type}/{object_id}/audits/{file_id}","request":{"parameters":{"path":{"type":{"type":"string","description":"The type of template to retrieve (scan or policy).","dropdown":true,"options":["scan","policy"],"required":true},"object_id":{"type":"integer","description":"The unique id of the object.","required":true},"file_id":{"type":"integer","description":"The id of the file to export.","required":true}}},"permissions":{"type":"policy","value":32}},"response":{"codes":{"200":{"description":"Returns the audit file."},"403":{"description":"Returned if the user does not have permission to export the audit file."},"404":{"description":"Returned if the audit file does not exist"}}}},"audits-token-download":{"description":"Export the given audit file for download using a single use token.","method":"GET","uri":"editor/{type}/{object_id}/audits/{file_id}/prepare","request":{"parameters":{"path":{"type":{"type":"string","description":"The type of template to retrieve (scan or policy).","dropdown":true,"options":["scan","policy"],"required":true},"object_id":{"type":"integer","description":"The unique id of the object.","required":true},"file_id":{"type":"integer","description":"The id of the file to export.","required":true}}},"permissions":{"type":"policy","value":32}},"response":{"codes":{"200":{"description":"Returns the an object with a token that can be used with the tokens API."},"403":{"description":"Returned if the user does not have permission to export the audit file."},"404":{"description":"Returned if the audit file does not exist"}}}},"details":{"description":"Returns details for the given template.","method":"GET","uri":"editor/{type}/templates/{template_uuid}","request":{"parameters":{"path":{"type":{"type":"string","description":"The type of template to retrieve (scan or policy).","dropdown":true,"options":["scan","policy"],"required":true},"template_uuid":{"type":"string","description":"The uuid for the template.","required":true}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the template details."},"403":{"description":"Returned if the user does not have permission to open the template."},"404":{"description":"Returned if the template does not exist."}},"sample":{"data":{"title":"string","name":"string","is_agent":"boolean","filter_attributes":["representation: editor.filter"],"settings":{"basic":{"title":"string","groups":["representation: editor.group"],"inputs":["representation: editor.input"]},"discovery":{"title":"string","groups":["representation: editor.group"],"modes":["representation: editor.mode"]},"assessment":{"title":"string","groups":["representation: editor.group"],"modes":["representation: editor.mode"]},"report":{"title":"string","modes":["representation: editor.mode"],"sections":["representation: editor.section"]},"advanced":{"title":"string","modes":["representation: editor.mode"],"sections":["representation: editor.section"]}},"credentials":{"data":["representation: editor.credential"]},"compliance":{"data":["representation: editor.audit"]},"plugins":{"families":["representation: editor.family"]}}}}},"edit":{"description":"Returns the requested object.","method":"GET","uri":"editor/{type}/{id}","request":{"parameters":{"path":{"type":{"type":"string","description":"The type of object (scan or policy).","dropdown":true,"options":["scan","policy"],"required":true},"id":{"type":"integer","description":"The unique id of the object.","required":true}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the object data."},"403":{"description":"Returned if the user does not have permission to open the object."},"404":{"description":"Returned if the object does not exist."}},"sample":{"data":{"uuid":"string","user_permissions":"integer","filter_attributes":["representation: editor.filter"],"settings":{"basic":{"title":"string","groups":["representation: editor.group"],"inputs":["representation: editor.input"]},"discovery":{"title":"string","groups":["representation: editor.group"],"modes":["representation: editor.mode"]},"assessment":{"title":"string","groups":["representation: editor.group"],"modes":["representation: editor.mode"]},"report":{"title":"string","modes":["representation: editor.mode"],"sections":["representation: editor.section"]},"advanced":{"title":"string","modes":["representation: editor.mode"],"sections":["representation: editor.section"]}},"credentials":{"data":["representation: editor.credential"]},"compliance":{"data":["representation: editor.audit"]},"plugins":{"families":["representation: editor.family"]}}}}},"list":{"description":"Returns the template list.","method":"GET","uri":"editor/{type}/templates","request":{"parameters":{"path":{"type":{"type":"string","description":"The type of templates to retrieve (scan or policy).","dropdown":true,"options":["scan","policy"],"required":true}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the template list."},"403":{"description":"Returned if the user does not have permission to view the list."}},"sample":{"data":{"templates":["representation: editor.template"]}}}},"plugin-description":{"description":"Returns the plugin description","method":"GET","uri":"editor/policy/{policy_id}/families/{family_id}/plugins/{plugin_id}","request":{"parameters":{"path":{"policy_id":{"type":"integer","description":"The id of the policy to lookup.","dropdown":false,"required":true},"family_id":{"type":"integer","description":"The id of the family to lookup within the policy.","dropdown":false,"required":true},"plugin_id":{"type":"integer","description":"The id of the plugin to lookup within the family.","dropdown":false,"required":true}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the plugin output."}},"sample":{"data":{"plugindescription":{"severity":"integer","pluginname":"string","pluginattributes":{"solution":"string","fname":"string","synopsis":"string","description":"string","rhsa":"string","alas":"string","see_also":["string"],"plugin_name":"string","osvdb":"string","risk_information":{"risk_factor":"string","cvss_base_score":"string","cvss_vector":"string","cvss_temporal_vector":"string","cvss_temporal_score":"string","stig_severity":"string"},"plugin_information":{"plugin_version":"string","plugin_id":"integer","plugin_type":"string","plugin_family":"string","plugin_publication_date":"string","plugin_modification_date":"string"},"vuln_information":{"cpe":"string","exploit_available":"string","exploitability_ease":"string","patch_publication_date":"string","vuln_publication_date":"string","exploit_frameworks":[{"name":"string","exploit":"string","package":"string"}]},"ref_information":{"ref":[{"ext":"string","name":"string","url":"string","values":["string"]}]}},"pluginfamily":"string","pluginid":"integer","classname":"string"}}}}}}},"file":{"name":"file","description":"","methods":{"upload":{"description":"Uploads a file.","method":"POST","uri":"file/upload","no_test":true,"request":{"parameters":{"payload":{"no_enc":{"type":"integer","description":"Send value of \"1\" when uploading an encrypted file.","required":false}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the file has been successfully uploaded."},"500":{"description":"Returned if the file failed to upload."}},"sample":{"data":{"fileuploaded":"string"}}}}}},"folders":{"name":"folders","description":"","representations":[{"name":"folder","description":"Folders are used to sort and organize a user's scan results.","parameters":{"id":{"type":"integer","description":"The unique id of the folder."},"name":{"type":"string","description":"The name of the folder."},"type":{"type":"string","description":"The type of the folder (main, trash, custom)."},"default_tag":{"type":"integer","description":"Whether or not the folder is the default (1 or 0)."},"custom":{"type":"integer","description":"The custom status of the folder (1 or 0)."},"unread_count":{"type":"integer","description":"The number of unread scans in the folder."}}}],"methods":{"create":{"description":"Create a new folder for the current user.","method":"POST","uri":"folders","request":{"parameters":{"payload":{"name":{"type":"string","description":"The name of the folder.","required":true}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the new folder id."},"400":{"description":"Returned if the folder name is invalid."},"403":{"description":"Returned if the user does not have permission to create a folder."},"500":{"description":"Returned if the server failed to create the folder."}}}},"delete":{"description":"Delete a folder.","method":"DELETE","uri":"folders/{folder_id}","request":{"parameters":{"path":{"folder_id":{"type":"integer","description":"The id of the folder to delete.","required":true}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the folder has been successfully deleted."},"403":{"description":"Returned if the user tried to delete a system folder."},"404":{"description":"Returned if the folder does not exist."},"500":{"description":"Returned if the server failed to delete the folder."}}}},"edit":{"description":"Rename a folder for the current user.","method":"PUT","uri":"folders/{folder_id}","request":{"parameters":{"path":{"folder_id":{"type":"integer","description":"The id of the folder to edit.","required":true}},"payload":{"name":{"type":"string","description":"The name of the folder.","required":true}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the folder has been successfully renamed."},"403":{"description":"Returned if the user tried to rename a system folder."},"404":{"description":"Returned if the folder does not exist."},"500":{"description":"Returned if the server failed to rename the folder."}}}},"list":{"description":"Returns the current user's scan folders.","method":"GET","uri":"folders","request":{"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the folder list."},"403":{"description":"Returned if the user does not have permission to view the list."}},"sample":{"data":{"folders":["representation: folders.folder"]}}}}}},"groups":{"name":"groups","description":"","manager_only":true,"representations":[{"name":"group","description":"Groups are utilized to make sharing easier.","parameters":{"id":{"type":"integer","description":"The unique id of the group."},"name":{"type":"string","description":"The name of the group."},"permissions":{"type":"integer","description":"The permissions for the group."},"user_count":{"type":"integer","description":"The number of users in the group."}}}],"methods":{"add-user":{"description":"Add a user to the group.","method":"POST","uri":"groups/{group_id}/users/{user_id}","request":{"parameters":{"path":{"group_id":{"type":"integer","description":"The unique id of the group.","required":true},"user_id":{"type":"integer","description":"The unique id of the user.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the user has been added to the group."},"403":{"description":"Returned if the user does not have permission to add users to a group."},"404":{"description":"Returned if the group or user does not exist."},"500":{"description":"Returned if the server failed to add the user to the group."}}}},"create":{"description":"Create a group.","method":"POST","uri":"groups","request":{"parameters":{"payload":{"name":{"type":"string","description":"The name of the group.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the group has been created."},"400":{"description":"Returned if a field is invalid."},"403":{"description":"Returned if the user does not have permission to create a group."},"500":{"description":"Returned if the server failed to add the group."}},"sample":{"data":"representation: groups.group"}}},"delete":{"description":"Delete a group.","method":"DELETE","uri":"groups/{group_id}","request":{"parameters":{"path":{"group_id":{"type":"integer","description":"The unique id of the group.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the group has been deleted."},"400":{"description":"Returned if the group does not exist."},"403":{"description":"Returned if the user does not have permission to delete the group."},"500":{"description":"Returned if the server failed to delete the group."}}}},"delete-bulk":{"description":"Delete groups in bulk.","method":"DELETE","uri":"groups","request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of group IDs to delete.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the groups have been deleted."},"400":{"description":"Returned if the groups do not exist."},"403":{"description":"Returned if the user does not have permission to delete the groups."},"500":{"description":"Returned if the server failed to delete the groups."}}}},"delete-user":{"description":"Delete a user from the group.","method":"DELETE","uri":"groups/{group_id}/users/{user_id}","request":{"parameters":{"path":{"group_id":{"type":"integer","description":"The unique id of the group.","required":true},"user_id":{"type":"integer","description":"The unique id of the user.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the user has been removed from the group."},"403":{"description":"Returned if the user does not have permission to delete users from a group."},"404":{"description":"Returned if the group or user does not exist."},"500":{"description":"Returned if the server failed to remove the user from the group."}}}},"edit":{"description":"Edit a group.","method":"PUT","uri":"groups/{group_id}","request":{"parameters":{"path":{"group_id":{"type":"integer","description":"The unique id of the group.","required":true}},"payload":{"name":{"type":"string","description":"The name of the group.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the group has been modified."},"400":{"description":"Returned if a field is invalid."},"403":{"description":"Returned if the user does not have permission to edit a group."},"404":{"description":"Returned if the group does not exist."},"500":{"description":"Returned if the server failed to edit the group."}},"sample":{"data":"representation: groups.group"}}},"list":{"description":"Returns the group list.","method":"GET","uri":"groups","request":{"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the groups list."},"403":{"description":"Returned if the user does not have permission to view the list."}},"sample":{"data":{"groups":["representation: groups.group"]}}}},"list-users":{"description":"Return the group user list.","method":"GET","uri":"groups/{group_id}/users","request":{"parameters":{"path":{"group_id":{"type":"integer","description":"The unique id of the group.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns if the group user list."},"403":{"description":"Returned if the user does not have permission to list a group's users."},"404":{"description":"Returned if the group does not exist."}},"sample":{"data":{"users":["representation: users.user"]}}}}}},"mail":{"name":"mail","description":"","methods":{"change":{"description":"Changes the mail server settings.","method":"PUT","uri":"settings/network/mail","request":{"parameters":{"payload":{"smtp_host":{"type":"string","description":"The mail server host.","required":false},"smtp_port":{"type":"integer","description":"The mail server port.","required":false},"smtp_from":{"type":"string","description":"The sender of mail messages.","required":false},"smtp_www_host":{"type":"string","description":"The host to use in email links.","required":false},"smtp_auth":{"type":"string","description":"The mail server authentication type.","required":true,"dropdown":true,"options":["NONE","PLAIN","LOGIN","NTLM","CRAM-MD5"]},"smtp_user":{"type":"string","description":"The sender's username.","required":false},"smtp_pass":{"type":"string","description":"The sender's password.","required":false},"smtp_enc":{"type":"string","description":"The encryption protocol to use.","required":true,"dropdown":true,"options":["No Encryption","Force SSL","Force TLS","Use TLS if available"]}}},"permissions":{"type":"user","value":128}},"response":{"codes":{"200":{"description":"Returned if the settings were changed successfully."},"403":{"description":"Returned if the user does not have permission to change the settings."}}}},"view":{"description":"Returns the mail server settings.","method":"GET","uri":"settings/network/mail","request":{"permissions":{"type":"user","value":128}},"response":{"codes":{"200":{"description":"Returns the mail settings."},"403":{"description":"Returned if the user does not have permission to view the settings."}},"sample":{"data":{"smtp_host":"string","smtp_port":"integer","smtp_from":"string","smtp_www_host":"string","smtp_auth":"string","smtp_user":"string","smtp_pass":"string","smtp_enc":"string"}}}}}},"migration":{"name":"migration","description":"","representations":"","methods":{"get-settings":{"description":"Returns the current migration settings.","method":"GET","uri":"migration/config","request":{"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the current migration settings."},"403":{"description":"Returned if the user does not have sufficient permissions."}},"sample":{"data":{"status":"not started","port":"443","linkingKey":"dc5c8817266e0bcfcf93501c45baa1832c2cb50a32bb10d02998f850f066bfd5","domain":"tenable.com","host":"cloud.tenable.com","name":"test migration"}}}},"update-settings":{"description":"Changes the migration settings.","method":"PUT","uri":"migration/config","request":{"permissions":{"type":"user","value":64},"parameters":{"payload":{"key":{"type":"string","description":"An access key can be generated from your administrator user account in Tenable.io."},"secret":{"type":"string","description":"An access key can be generated from your administrator user account in Tenable.io."},"domain":{"type":"string","description":"The domain name to use when migrating users."}}}},"response":{"codes":{"200":{"description":"Changes the migration settings."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}},"status":{"description":"Returns the migration status.","method":"GET","uri":"migration","request":{"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the migration status."},"403":{"description":"Returned if the user does not have sufficient permissions."}},"sample":{"data":{"transient":0,"critical":0,"current":"Migrating local scanner","error":"","progress":90,"status":"started"}}}},"start":{"description":"Starts or resumes the migration. Before you start the migration, you need have the 'key', 'secret' and 'domain' settings set.","method":"POST","uri":"migration","request":{"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the migration started successfully."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}},"stop":{"description":"Finishes or stops the migration.","method":"DELETE","uri":"migration","request":{"parameters":{"query":{"finish":{"type":"boolean","description":"If true, finish the migration; otherwise, cancel the migration","required":false}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the migration is finished or canceled successfully."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}},"scan-history":{"description":"Returns the scan history migration status.","method":"GET","uri":"migration/scan-history","request":{"parameters":{"query":{"updatedAfter":{"type":"integer","description":"The timestamp threshold of the item get updated. If there is no item gets updated after this timestamp, we return empty status, otherwise we return the current status.","required":false}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the scan history migration status."},"403":{"description":"Returned if the user does not have sufficient permissions."}},"sample":{"data":{"totalCount":5,"totalBytes":54493184,"uploadedCount":1,"uploadedBytes":216064,"skippedCount":1,"skippedBytes":215040,"uploadCount":3,"uploadBytes":54062080,"uploadingStopped":false,"items":[{"upload_status":"","bytes":215040,"last_modification_date":1542402549,"name":"test host discovery","uuid":"f4a44006-c5e8-45cf-2188-64f79d44c2c5ea86524cdfcdb528","message":"","status":"skipped","id":8},{"upload_status":"","bytes":216064,"last_modification_date":1542307330,"name":"test host discovery","uuid":"5b7b023a-7d1d-9d2d-e639-a85de5b8683f3629dc7afbcb64af","message":"","status":"finished","id":9},{"upload_status":"","bytes":17881088,"last_modification_date":1542137211,"owner":"admin","name":"test advanced scan","uuid":"cea9e002-dc9b-6247-67e6-e092c92c72f94f75a5c95e8d6674","message":"","status":"not started","id":10}]}}}},"scan-history-settings":{"description":"Returns the current scan history migration settings.","method":"GET","uri":"migration/scan-history/upload-settings","request":{"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the current scan history migration settings."},"403":{"description":"Returned if the user does not have sufficient permissions."}},"sample":{"data":{"days_of_history":10,"concurrent_uploads":1,"seconds_to_sleep_between_each_upload":5}}}},"update-scan-history-settings":{"description":"Changes the scan history migration settings.","method":"POST","uri":"migration/scan-history/upload-settings","request":{"permissions":{"type":"user","value":64},"parameters":{"payload":{"settings":{"name":"settings","object":true,"inputs":{"days_of_history":{"type":"integer","description":"The days of scan history to migrate. 0 means migrate all the scan histories.","required":true},"concurrent_uploads":{"type":"integer","description":"The concurrent number of scan histories to migrate. Default is 1.","required":false},"seconds_to_sleep_between_each_upload":{"type":"integer","description":"The number of seconds to pause after one item finished migration. Default is 0.","required":false}}}}},"sample":{"data":{"settings":{"days_of_history":10,"concurrent_uploads":1,"seconds_to_sleep_between_each_upload":10}}}},"response":{"codes":{"200":{"description":"Successfully updated scan history migration settings."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}},"start-scan-history-migration":{"description":"Starts the scan history migration process.","method":"POST","uri":"migration/scan-history/start-upload","request":{"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Successfully started the scan history migration."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}},"stop-scan-history-migration":{"description":"Stops the scan history migration process.","method":"POST","uri":"migration/scan-history/stop-upload","request":{"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Successfully stopped the scan history migration."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}},"skip-scan-history":{"description":"Skips migrating a single scan history item.","method":"POST","uri":"migration/scan-history/{scan_uuid}/skip-upload","request":{"parameters":{"path":{"scan_uuid":{"type":"string","description":"The uuid of the scan history item to skip.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Successfully marked the scan history item as to be skipped."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}},"skip-scan-history-bulk":{"description":"Skips migrating scan history items in bulk.","method":"POST","uri":"migration/scan-history/skip-upload","request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of scan history uuids to skip.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Successfully marked scan history items to be skipped."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}},"reset-scan-history":{"description":"Resets a scan history item's status to 'not started' so it will be migrated.","method":"POST","uri":"migration/scan-history/{scan_uuid}/start-upload","request":{"parameters":{"path":{"scan_uuid":{"type":"string","description":"The uuid of the scan history item to reset.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Successfully updated a scan history item's status."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}},"reset-scan-history-bulk":{"description":"Resets the status of the scan history items matching the provided IDs so they can be migrated.","method":"POST","uri":"migration/scan-history/start-upload","request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of scan history item uuids to reset.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Successfully updated scan history items' statuses."},"403":{"description":"Returned if the user does not have sufficient permissions."}}}}}},"permissions":{"name":"permissions","description":"","representations":[{"name":"permission","description":"Permissions are used to provide access rights to a given object.","parameters":{"owner":{"type":"integer","description":"The unique id of the owner of the object."},"type":{"type":"string","description":"The type of permission (default, user, group)."},"permissions":{"type":"integer","description":"The permission value (0, 16, 32, 64) to grant access as described <a href=\"#/authorization\">here</a>."},"id":{"type":"integer","description":"The unique id of the user if type is user."},"name":{"type":"string","description":"The name of the user or group."}}}],"methods":{"change":{"description":"Changes the permissions for an object.","method":"PUT","uri":"permissions/{object_type}/{object_id}","request":{"parameters":{"path":{"object_type":{"type":"string","description":"The type of object.","required":true,"dropdown":true,"options":["scanner"]},"object_id":{"type":"integer","description":"The unique id of the object.","required":true}},"body":{"Request Body":{"type":"request_body","description":"An array of permission resources to apply to the object.","required":true,"placeholder":"{\"acls\": [{\"type\": \"default\", \"permissions\": 16}, {\"type\": \"user\", \"permissions\": 64, \"name\": \"admin\", \"id\": 1, \"owner\": 1}]}"}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returned if the object was changed successfully."},"403":{"description":"Returned if the user does not have permission to edit the object."},"404":{"description":"Returned if the object does not exist."}}}},"list":{"description":"Returns the current object's permissions.","method":"GET","uri":"permissions/{object_type}/{object_id}","request":{"parameters":{"path":{"object_type":{"type":"string","description":"The type of object.","required":true,"dropdown":true,"options":["scanner"]},"object_id":{"type":"integer","description":"The unique id of the object.","required":true}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the object permissions."},"403":{"description":"Returned if the user does not have permission to view the object."},"404":{"description":"Returned if the object does not exist."}},"sample":{"data":["representation: permissions.permission"]}}}}},"plugin-rules":{"name":"plugin-rules","description":"","representations":[{"name":"rule","description":"Plugin rules are used to change the severity of vulnerabilities in scan results.","parameters":{"id":{"type":"integer","description":"The unique id of the plugin rule."},"plugin_id":{"type":"integer","description":"The unique id of the plugin to which the rule applies."},"date":{"type":"string","description":"The expiration date for the rule in unixtime."},"host":{"type":"string","description":"The host to which the rule applies."},"type":{"type":"string","description":"The new severity of the plugin attached to the rule."},"owner":{"type":"string","description":"The name of the owner of the rule."},"owner_id":{"type":"integer","description":"The unique id of the owner of the rule."}}}],"methods":{"create":{"description":"Create a new plugin rule for the current user.","method":"POST","uri":"plugin-rules","request":{"parameters":{"payload":{"plugin_id":{"type":"integer","description":"The id of the plugin to apply the rule to (i.e. 12345).","required":true},"type":{"type":"string","description":"The new severity to apply (recast_critical, recast_high, recast_medium, recast_low, recast_info, exclude).","required":true,"dropdown":true,"options":["recast_critical","recast_high","recast_medium","recast_low","recast_info","exclude"]},"host":{"type":"string","description":"The host to apply the rule to.","required":true},"date":{"type":"string","description":"The expiration date of the plugin rule."}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the rule was created successfully."},"400":{"description":"Returned if an argument is missing or invalid."},"403":{"description":"Returned if the user does not have permission to create a rule."},"500":{"description":"Returned if the server failed to create the rule."}}}},"delete":{"description":"Delete a plugin rule.","method":"DELETE","uri":"plugin-rules/{rule_id}","request":{"parameters":{"path":{"rule_id":{"type":"integer","description":"The id of the rule to delete.","required":true}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the rule has been succesfully deleted."},"403":{"description":"Returned if the user does not have permission to delete the rule."},"404":{"description":"Returned if the rule does not exist."}}}},"delete-bulk":{"description":"Delete plugin rules in bulk.","method":"DELETE","uri":"plugin-rules","request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of plugin IDs to delete.","required":true}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the plugin rules have been successfully deleted."},"400":{"description":"Returned if any of the plugin rule IDs are invalid."},"500":{"description":"Returned if the server failed to delete the plugin rules."}},"sample":{"data":{"deleted":"array"}}}},"edit":{"description":"Modify a plugin rule for the current user.","method":"PUT","uri":"plugin-rules/{rule_id}","request":{"parameters":{"path":{"rule_id":{"type":"integer","description":"The id of the rule to edit.","required":true}},"payload":{"plugin_id":{"type":"integer","description":"The id of the plugin to apply the rule to (i.e. 12345).","required":true},"type":{"type":"string","description":"The new severity to apply (recast_critical, recast_high, recast_medium, recast_low, recast_info, exclude).","required":true,"dropdown":true,"options":["recast_critical","recast_high","recast_medium","recast_low","recast_info","exclude"]},"host":{"type":"string","description":"The host to apply the rule to.","required":true},"date":{"type":"string","description":"The expiration date of the plugin rule."}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the rule has been modified."},"403":{"description":"Returned if the user does not have permission to modify the rule."},"404":{"description":"Returned if the rule does not exist."},"500":{"description":"Returned if the server failed to change the rule."}}}},"list":{"description":"Return the current user's plugin rules.","method":"GET","uri":"plugin-rules","request":{"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the plugin rules list."},"403":{"description":"Returned if the user does not have permission to view the list."}},"sample":{"data":{"plugin_rules":["representation: plugin-rules.rule"]}}}},"details":{"description":"Returns the details for a given rule.","method":"GET","uri":"plugin-rules/{rule_id}","request":{"parameters":{"path":{"rule_id":{"type":"integer","description":"The id of the rule.","required":true}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the rule details."},"403":{"description":"Returned if the user does not have permission to view the rule."},"404":{"description":"Returned if the rule does not exist."}},"sample":{"data":"representation: plugin-rules.rule"}}}}},"plugins":{"name":"plugins","description":"","representations":[{"name":"attribute","description":"The attributes for a given plugin.","parameters":{"attribute_name":{"type":"string","description":"The name of the attribute."},"attribute_value":{"type":"string","description":"The value of the attribute."}}},{"name":"family","description":"Plugin families are used to organize and group plugins.","parameters":{"id":{"type":"integer","description":"The unique id of the family."},"name":{"type":"string","description":"The name of the family."},"count":{"type":"integer","description":"The number of plugins in the family."}}},{"name":"plugin","description":"The name and id of a family plugin.","parameters":{"id":{"type":"integer","description":"The id of the plugin."},"name":{"type":"string","description":"The name of the plugin."}}}],"methods":{"families":{"description":"Returns the list of plugin families.","method":"GET","uri":"plugins/families","request":{"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the list of plugin families."}},"sample":{"data":{"families":["representation: plugins.family"]}}}},"family-details":{"description":"Returns the list of plugins in a family.","method":"GET","uri":"plugins/families/{id}","request":{"parameters":{"path":{"id":{"type":"integer","description":"The id of the family to lookup.","dropdown":false,"required":true}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the list of plugins in a family."}},"sample":{"data":{"name":"string","id":"integer","plugins":["representation: plugins.plugin"]}}}},"plugin-details":{"description":"Returns details for a given plugin.","method":"GET","uri":"plugins/plugin/{id}","request":{"parameters":{"path":{"id":{"type":"integer","description":"The id of the plugin.","required":true}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the plugin details."}},"sample":{"data":{"id":"integer","name":"string","family_name":"string","attributes":["representation: plugins.attribute"]}}}}}},"policies":{"name":"policies","description":"","representations":[{"name":"policy","description":"Policies are used to define scan test parameters.","parameters":{"id":{"type":"integer","description":"The unique id of the policy."},"template_uuid":{"type":"string","description":"The uuid for the template the policy uses."},"name":{"type":"string","description":"The name of the policy."},"description":{"type":"string","description":"The description of the policy."},"owner_id":{"type":"string","description":"The unique id of the owner of the policy."},"owner":{"type":"string","description":"The username for the owner of the policy."},"shared":{"type":"integer","description":"The shared status of the policy."},"user_permissions":{"type":"integer","description":"The sharing permissions for the policy."},"creation_date":{"type":"integer","description":"The creation date of the policy in unixtime."},"last_modification_date":{"type":"integer","description":"The last modification date for the policy in unixtime."},"visibility":{"type":"integer","description":"The visibility of the target (private or shared)."},"no_target":{"type":"boolean","description":"If true, the policy does not use targets."},"has_credentials":{"type":"integer","description":"If 1, the policy has credentials."},"is_scap":{"type":"integer","description":"If 1, the policy uses a SCAP template."}}}],"methods":{"configure":{"description":"Changes the parameters of a policy.","method":"PUT","uri":"policies/{policy_id}","no_test":true,"request":{"description":"These parameters, in addition to those returned by <a href=\"#/resources/editor/details\">editor: details</a>, are all required for configuring an existing policy. A sample request body is provided below.","parameters":{"path":{"policy_id":{"type":"integer","description":"The id of the policy to change.","required":true}}},"permissions":{"type":"policy","value":32},"sample":{"data":{"uuid":"var:template_uuid","audits":{"feed":{"add":[{"id":"var:audit_id","variables":{"1":"var:audit_variable_value","2":"var:audit_variable_value","3":"var:audit_variable_value"}}]}},"credentials":{"add":{"var:credential_category":{"var:credential_name":[{"var:credential_input_name":"string"}]}},"edit":{"var:credential_id":{"var:credential_input_name":"string"}},"delete":["var:credential_id"]},"plugins":{"var:plugin_family_name":{"status":"string","individual":{"var:plugin_id":"string"}}},"scap":{"add":{"var:scap_category":[{"var:scap_input_name":"string"}]},"edit":{"var:scap_id":{"var:scap_input_name":"string"}},"delete":["var:scap_id"]},"settings":{"acls":["representation: permissions.permission"],"additional_snmp_port1":"string","additional_snmp_port2":"string","additional_snmp_port3":"string","adtran_aos_offline_configs":"string","allow_post_scan_editing":"string","apm_force_updates":"string","apm_update_timeout":"string","arp_ping":"string","av_grace_period":"string","aws_ap_northeast_1":"string","aws_ap_southeast_1":"string","aws_ap_southeast_2":"string","aws_eu_west_1":"string","aws_sa_east_1":"string","aws_ui_region_type":"string","aws_us_east_1":"string","aws_us_gov_west_1":"string","aws_us_west_1":"string","aws_us_west_2":"string","aws_use_https":"string","aws_verify_ssl":"string","brocade_offline_configs":"string","check_crl":"string","cisco_config_to_audit":"string","cisco_offline_configs":"string","dell_f10_offline_configs":"string","description":"string","detect_ssl":"string","display_unreachable_hosts":"string","dont_use_ntlmv1":"string","enable_admin_shares":"string","enum_domain_users_end_uid":"string","enum_domain_users_start_uid":"string","enum_local_users_end_uid":"string","enum_local_users_start_uid":"string","enumerate_all_ciphers":"string","extremeos_offline_configs":"string","fast_network_discovery":"string","fireeye_offline_configs":"string","host_whitelist":"string","http_login_auth_regex_nocase":"string","http_login_auth_regex_on_headers":"string","http_login_invert_auth_regex":"string","http_login_max_redir":"string","http_login_method":"string","huawei_offline_configs":"string","icmp_ping":"string","icmp_ping_retries":"string","icmp_unreach_means_host_down":"string","junos_offline_configs":"string","log_live_hosts":"string","log_whole_attack":"string","max_checks_per_host":"string","max_hosts_per_scan":"string","max_simult_tcp_sessions_per_host":"string","max_simult_tcp_sessions_per_scan":"string","modbus_end_reg":"string","modbus_start_reg":"string","name":"string","netapp_offline_configs":"string","network_receive_timeout":"string","network_type":"string","never_send_win_creds_in_the_clear":"string","only_portscan_if_enum_failed":"string","patch_audit_over_rexec":"string","patch_audit_over_rsh":"string","patch_audit_over_telnet":"string","ping_the_remote_host":"string","portscan_range":"string","procurve_config_to_audit":"string","procurve_offline_configs":"string","provided_creds_only":"string","reduce_connections_on_congestion":"string","report_paranoia":"string","report_superseded_patches":"string","report_verbosity":"string","request_windows_domain_info":"string","reverse_lookup":"string","safe_checks":"string","scan_netware_hosts":"string","scan_network_printers":"string","scan_webapps":"string","silent_dependencies":"string","slice_network_addresses":"string","smtp_domain":"string","smtp_from":"string","smtp_to":"string","snmp_port":"string","snmp_scanner":"string","sonicos_offline_configs":"string","ssh_client_banner":"string","ssh_known_hosts":"string","ssh_netstat_scanner":"string","ssh_port":"string","ssl_prob_ports":"string","start_cotp_tsap":"string","start_remote_registry":"string","stop_cotp_tsap":"string","stop_scan_on_disconnect":"string","svc_detection_on_all_ports":"string","syn_firewall_detection":"string","syn_scanner":"string","tcp_ping":"string","tcp_ping_dest_ports":"string","test_default_oracle_accounts":"string","test_local_nessus_host":"string","thorough_tests":"string","udp_ping":"string","udp_scanner":"string","unscanned_closed":"string","verify_open_ports":"string","win_known_bad_hashes":"string","win_known_good_hashes":"string","wmi_netstat_scanner":"string","wol_mac_addresses":"string","wol_wait_time":"string"}}}},"response":{"codes":{"200":{"description":"Returned if the configuration was changed."},"404":{"description":"Returned if the policy does not exist."},"500":{"description":"Returned if an error occurred while saving the configuration."}}}},"copy":{"description":"Copy a policy.","method":"POST","uri":"policies/{policy_id}/copy","request":{"parameters":{"path":{"policy_id":{"type":"integer","description":"The id of the policy to copy.","required":true}}},"permissions":{"type":"policy","value":32}},"response":{"codes":{"200":{"description":"Returns the policy object."},"403":{"description":"Returned if the user does not have permission to copy the policy."},"404":{"description":"Returned if the policy does not exist."},"500":{"description":"Returned if the server failed to copy the policy."}}}},"create":{"description":"Create a policy.","method":"POST","uri":"policies","no_test":true,"request":{"description":"Policies are created by sending the below fields, along with those returned by <a href=\"#/resources/editor/details\">editor: details</a>, to this route. A sample request body is provided below.","parameters":{"payload":{"uuid":{"type":"string","description":"The uuid for the editor template to use.","required":true,"placeholder":"ab4bacd2-05f6-425c-9d79-3ba3940ad1c24e51e1f403febe40"},"settings":{"name":"settings","object":true}}},"permissions":{"type":"user","value":32},"sample":{"data":{"uuid":"var:template_uuid","audits":{"feed":{"add":[{"id":"var:audit_id","variables":{"1":"var:audit_variable_value","2":"var:audit_variable_value","3":"var:audit_variable_value"}}]}},"credentials":{"add":{"var:credential_category":{"var:credential_name":[{"var:credential_input_name":"string"}]}}},"plugins":{"var:plugin_family_name":{"status":"string","individual":{"var:plugin_id":"string"}}},"scap":{"add":{"var:scap_category":[{"var:scap_input_name":"string"}]}},"settings":{"acls":["representation: permissions.permission"],"additional_snmp_port1":"string","additional_snmp_port2":"string","additional_snmp_port3":"string","adtran_aos_offline_configs":"string","allow_post_scan_editing":"string","apm_force_updates":"string","apm_update_timeout":"string","arp_ping":"string","av_grace_period":"string","aws_ap_northeast_1":"string","aws_ap_southeast_1":"string","aws_ap_southeast_2":"string","aws_eu_west_1":"string","aws_sa_east_1":"string","aws_ui_region_type":"string","aws_us_east_1":"string","aws_us_gov_west_1":"string","aws_us_west_1":"string","aws_us_west_2":"string","aws_use_https":"string","aws_verify_ssl":"string","brocade_offline_configs":"string","check_crl":"string","cisco_config_to_audit":"string","cisco_offline_configs":"string","dell_f10_offline_configs":"string","description":"string","detect_ssl":"string","display_unreachable_hosts":"string","dont_use_ntlmv1":"string","enable_admin_shares":"string","enum_domain_users_end_uid":"string","enum_domain_users_start_uid":"string","enum_local_users_end_uid":"string","enum_local_users_start_uid":"string","enumerate_all_ciphers":"string","extremeos_offline_configs":"string","fast_network_discovery":"string","fireeye_offline_configs":"string","host_whitelist":"string","http_login_auth_regex_nocase":"string","http_login_auth_regex_on_headers":"string","http_login_invert_auth_regex":"string","http_login_max_redir":"string","http_login_method":"string","huawei_offline_configs":"string","icmp_ping":"string","icmp_ping_retries":"string","icmp_unreach_means_host_down":"string","junos_offline_configs":"string","log_live_hosts":"string","log_whole_attack":"string","max_checks_per_host":"string","max_hosts_per_scan":"string","max_simult_tcp_sessions_per_host":"string","max_simult_tcp_sessions_per_scan":"string","modbus_end_reg":"string","modbus_start_reg":"string","name":"string","netapp_offline_configs":"string","network_receive_timeout":"string","network_type":"string","never_send_win_creds_in_the_clear":"string","only_portscan_if_enum_failed":"string","patch_audit_over_rexec":"string","patch_audit_over_rsh":"string","patch_audit_over_telnet":"string","ping_the_remote_host":"string","portscan_range":"string","procurve_config_to_audit":"string","procurve_offline_configs":"string","provided_creds_only":"string","reduce_connections_on_congestion":"string","report_paranoia":"string","report_superseded_patches":"string","report_verbosity":"string","request_windows_domain_info":"string","reverse_lookup":"string","safe_checks":"string","scan_netware_hosts":"string","scan_network_printers":"string","scan_webapps":"string","silent_dependencies":"string","slice_network_addresses":"string","smtp_domain":"string","smtp_from":"string","smtp_to":"string","snmp_port":"string","snmp_scanner":"string","sonicos_offline_configs":"string","ssh_client_banner":"string","ssh_known_hosts":"string","ssh_netstat_scanner":"string","ssh_port":"string","ssl_prob_ports":"string","start_cotp_tsap":"string","start_remote_registry":"string","stop_cotp_tsap":"string","stop_scan_on_disconnect":"string","svc_detection_on_all_ports":"string","syn_firewall_detection":"string","syn_scanner":"string","tcp_ping":"string","tcp_ping_dest_ports":"string","test_default_oracle_accounts":"string","test_local_nessus_host":"string","thorough_tests":"string","udp_ping":"string","udp_scanner":"string","unscanned_closed":"string","verify_open_ports":"string","win_known_bad_hashes":"string","win_known_good_hashes":"string","wmi_netstat_scanner":"string","wol_mac_addresses":"string","wol_wait_time":"string"}}}},"response":{"codes":{"200":{"description":"Returned if the policy was saved successfully."},"500":{"description":"Returned if an error occurred while saving the policy."}},"sample":{"data":{"policy_id":"integer","policy_name":"string"}}}},"delete":{"description":"Delete a policy.","method":"DELETE","uri":"policies/{policy_id}","request":{"parameters":{"path":{"policy_id":{"type":"integer","description":"The id of the policy to delete.","required":true}}},"permissions":{"type":"policy","value":32}},"response":{"codes":{"200":{"description":"Returned if the server deleted the policy."},"403":{"description":"Returned if the user does not have permission to delete the policy."},"404":{"description":"Returned if the policy does not exist."},"405":{"description":"Returned if the policy is in use by a scan."}}}},"delete-bulk":{"description":"Delete policies in bulk.","method":"DELETE","uri":"policies","request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of policy IDs to delete.","required":true}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the policies have been successfully deleted."},"400":{"description":"Returned if any of the policy IDs are invalid."},"500":{"description":"Returned if the server failed to delete the policies."}},"sample":{"data":{"deleted":"array"}}}},"details":{"description":"Returns details for the given policy.","method":"GET","uri":"policies/{policy_id}","request":{"parameters":{"path":{"policy_id":{"type":"integer","description":"The id of the policy to retrieve.","required":true}}},"permissions":{"type":"policy","value":16}},"response":{"codes":{"200":{"description":"Returns the policy details. This response can be edited and passed directly to <a href=\"#/resources/policies/configure\">policies: configure</a>."}},"sample":{"data":{"uuid":"string","audits":{"feed":{"add":[{"id":"var:audit_id","variables":{"1":"var:audit_variable_value","2":"var:audit_variable_value","3":"var:audit_variable_value"}}]}},"credentials":{"edit":{"var:credential_id":{"var:credential_input_name":"string"}}},"plugins":{"var:plugin_family_name":{"status":"string","individual":{"var:plugin_id":"string"}}},"scap":{"edit":{"var:scap_id":{"var:scap_input_name":"string"}}},"settings":{"name":"string","wol_mac_addresses":"string","tcp_ping_dest_ports":"string","report_superseded_patches":"string","http_login_max_redir":"string","snmp_port":"string","icmp_ping":"string","description":"string","wmi_netstat_scanner":"string","never_send_win_creds_in_the_clear":"string","network_type":"string","udp_scanner":"string","icmp_unreach_means_host_down":"string","scan_network_printers":"string","syn_firewall_detection":"string","icmp_ping_retries":"string","scan_netware_hosts":"string","network_receive_timeout":"string","tcp_scanner":"string","tcp_ping":"string","additional_snmp_port1":"string","fast_network_discovery":"string","arp_ping":"string","enable_admin_shares":"string","test_local_nessus_host":"string","patch_audit_over_telnet":"string","additional_snmp_port2":"string","unscanned_closed":"string","ssh_netstat_scanner":"string","ssh_client_banner":"string","ssh_port":"string","only_portscan_if_enum_failed":"string","tcp_firewall_detection":"string","max_checks_per_host":"string","dont_use_ntlmv1":"string","max_hosts_per_scan":"string","verify_open_ports":"string","patch_audit_over_rexec":"string","wol_wait_time":"string","patch_audit_over_rsh":"string","ping_the_remote_host":"string","http_login_invert_auth_regex":"string","http_login_auth_regex_on_headers":"string","udp_ping":"string","http_login_method":"string","syn_scanner":"string","scan_webapps":"string","portscan_range":"string","http_login_auth_regex_nocase":"string","additional_snmp_port3":"string","snmp_scanner":"string","start_remote_registry":"string"}}}}},"import":{"description":"Import an existing policy uploaded using <a href=\"#/resources/file/upload\">file: upload</a> (.nessus format only).","method":"POST","uri":"policies/import","request":{"parameters":{"payload":{"file":{"type":"string","description":"The name of the file to import as provided by the response from <a href=\"#/resources/file/upload\">file: upload</a>.","required":true}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the policy object."},"500":{"description":"Returned if the server failed to import the policy."}}}},"export":{"description":"Export the given policy.","method":"DOWNLOAD","uri":"policies/{policy_id}/export","request":{"parameters":{"path":{"policy_id":{"type":"integer","description":"The id of the policy to export.","required":true}}},"permissions":{"type":"policy","value":32}},"response":{"codes":{"200":{"description":"Returns the policy in nessus (XML) format."},"403":{"description":"Returned if the user does not have permission to export the policy."},"404":{"description":"Returned if the policy does not exist"}}}},"export-token-download":{"description":"Export the given policy for download via a single use token.","method":"GET","uri":"policies/{policy_id}/export/prepare","request":{"parameters":{"path":{"policy_id":{"type":"integer","description":"The id of the policy to export.","required":true}}},"permissions":{"type":"policy","value":32}},"response":{"codes":{"200":{"description":"Returns an object with a token that can be used with the tokens API."},"403":{"description":"Returned if the user does not have permission to export the policy."},"404":{"description":"Returned if the policy does not exist"}},"sample":{"data":{"token":"string"}}}},"list":{"description":"Returns the policy list.","method":"GET","uri":"policies","request":{"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the policy list."},"403":{"description":"Returned if the user does not have permission to view the policy list."}},"sample":{"data":{"policies":["representation: policies.policy"]}}}}}},"proxy":{"name":"proxy","description":"","methods":{"change":{"description":"Changes the proxy settings.","method":"PUT","uri":"settings/network/proxy","request":{"parameters":{"payload":{"proxy":{"type":"string","description":"The proxy host.","required":false},"proxy_auth":{"type":"string","description":"The proxy auth method.","dropdown":true,"options":["auto","none","basic","digest","ntlm"],"required":false},"proxy_password":{"type":"string","description":"The proxy password.","required":false},"proxy_port":{"type":"integer","description":"The proxy port.","required":false},"proxy_username":{"type":"string","description":"The proxy username.","required":false},"user_agent":{"type":"string","description":"The proxy user-agent.","required":false}}},"permissions":{"type":"user","value":128}},"response":{"codes":{"200":{"description":"Returned if the settings were changed successfully."},"403":{"description":"Returned if the user does not have permission to change the settings."}}}},"view":{"description":"Returns the proxy settings.","method":"GET","uri":"settings/network/proxy","request":{"permissions":{"type":"user","value":128}},"response":{"codes":{"200":{"description":"Returns the proxy settings."},"403":{"description":"Returned if the user does not have permission to view the settings."}},"sample":{"data":{"proxy":"string","proxy_auth":"string","proxy_password":"string","proxy_port":"integer","proxy_username":"string","user_agent":"string"}}}}}},"scanners":{"name":"scanners","description":"","representations":[{"name":"aws-target","description":"The details of an Amazon Web Services scan target.","parameters":{"scanner_id":{"type":"integer","description":"The id of the scanner."},"instance_id":{"type":"string","description":"Unique instance identifier from Amazon."},"private_ip":{"type":"string","description":"Private IP address of the AWS instance."},"public_ip":{"type":"string","description":"Public IP address of the AWS instance."},"state":{"type":"string","description":"The state of the instance. Can be one of the following values: 'running', 'stopped', or 'terminated'."},"zone":{"type":"string","description":"The availability zone for the instance. Example: 'us-east-1a', 'us-east-1b', etc..."},"type":{"type":"string","description":"The size of the instance. Example: 't2.small', 't2.medium', etc..."},"name":{"type":"string","description":"The user-defined name of the instance."}}},{"name":"scan","description":"The details of a scan.","parameters":{"scanner_uuid":{"type":"string","description":"The uuid of the scanner the scan belongs to."},"name":{"type":"string","description":"The name of the scan."},"status":{"type":"string","description":"Scan status. One of pending, processing, stopping, pausing, paused, resuming, or running."},"id":{"type":"string","description":"The scan uuid."},"scan_id":{"type":"integer","description":"The id of the scan."},"user":{"type":"string","description":"The username of the owner of the scan."},"last_modification_date":{"type":"integer","description":"The last time the scan was modified."},"start_time":{"type":"integer","description":"When the scan was started."},"remote":{"type":"boolean","description":"true if the scan is running remotely; false otherwise."}}},{"name":"scanner","description":"The details of a scanner.","parameters":{"id":{"type":"integer","description":"The unique id of the scanner."},"uuid":{"type":"string","description":"The uuid of the scanner."},"name":{"type":"string","description":"The user-defined name of the scanner."},"type":{"type":"string","description":"The type of scanner (local or remote)."},"status":{"type":"string","description":"The status of the scanner (on or off)."},"scan_count":{"type":"integer","description":"The current number of running scans on the scanner."},"engine_version":{"type":"string","description":"The version of the scanner."},"platform":{"type":"string","description":"The platform of the scanner."},"loaded_plugin_set":{"type":"string","description":"The current plugin set on the scanner."},"registration_code":{"type":"string","description":"The registration code of the scanner."},"owner":{"type":"string","description":"The owner of the scanner."},"key":{"type":"string","description":"A alpha-numeric sequence of characters used when linking a scanner to Nessus."},"license":{"type":"object","description":"The license information for the scanner.","parameters":{"type":{"type":"string","description":"The license type."},"ips":{"type":"integer","description":"The number of hosts the scanner is licensed to use."},"agents":{"type":"integer","description":"The number of hosts agents scanner is licensed to use."},"scanners":{"type":"integer","description":"The number of scanners the scanner is licensed to use."}}}}}],"methods":{"control-scans":{"description":"Allows control of scans that are currently running on a scanner.","method":"POST","manager_only":true,"uri":"scanners/{scanner_id}/scans/{scan_uuid}/control","request":{"permissions":{"type":"user","value":64},"parameters":{"path":{"scanner_id":{"type":"integer","description":"The id of the scanner.","required":true},"scan_uuid":{"type":"string","description":"The uuid of the scan.","required":true}},"payload":{"action":{"type":"string","description":"An action to perform on a scan. Valid values are stop, pause, and resume.","required":true}}}},"response":{"codes":{"200":{"description":"Returned if the call was successful."},"403":{"description":"Returned if user does not have adequate permission."},"404":{"description":"Returned if the scan or scanner does not exist."}}}},"delete":{"description":"Delete and unlink a scanner from Nessus.","method":"DELETE","uri":"scanners/{scanner_id}","request":{"parameters":{"path":{"scanner_id":{"type":"integer","description":"The id of the scanner.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the server deleted/unlinked the scanner."},"403":{"description":"Returned if an attempt is made to delete the local scanner."},"500":{"description":"Returned if the server failed to delete the scanner."}}}},"delete-bulk":{"description":"Delete and unlink a list of scanners from Nessus.","method":"DELETE","uri":"scanners","request":{"parameters":{"payload":{"ids":{"type":"array","description":"The array of scanner ids.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the server deleted/unlinked the scanners."},"403":{"description":"Returned if the user does not have adequate permissions or an attempt is made to delete the local scanner."},"404":{"description":"Returned if any of the specified scanners do not exist."},"500":{"description":"Returned if the server failed to delete the scanners."}},"sample":{"data":{"deleted":"array"}}}},"details":{"description":"Returns details for the given scanner.","method":"GET","uri":"scanners/{scanner_id}","request":{"parameters":{"path":{"scanner_id":{"type":"integer","description":"The id of the scanner.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the scanner details."},"403":{"description":"Returned if user does not have permission to view the scanner."},"404":{"description":"Returned if the scanner does not exist."}},"sample":{"data":"representation: scanners.scanner"}}},"edit":{"description":"Edit the scanner identified by 'scanner_id'.","method":"PUT","uri":"scanners/{scanner_id}","request":{"parameters":{"path":{"scanner_id":{"type":"integer","description":"The id of the scanner.","required":true}},"payload":{"force_plugin_update":{"type":"integer","description":"Pass 1 to force a plugin update.","required":false},"force_ui_update":{"type":"integer","description":"Pass 1 to force a UI update.","required":false},"finish_update":{"type":"integer","description":"Pass 1 to reboot the scanner and run the latest software update (only valid if automatic updates are disabled).","required":false},"registration_code":{"type":"string","description":"Sets the registration code for the scanner.","required":false},"aws_update_interval":{"type":"integer","description":"For Amazon Web Services scanners this will tell the scanner how often to check in to Nessus.","required":false}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if updating the scanner was successful."},"403":{"description":"Returned if the scanner is a cloud scanner and the user doesn’t have permission to edit it, or if trying to set a registration code for an Amazon Web Services scanner."},"500":{"description":"Returned if an internal error prevented the update from completing."}}}},"get-aws-targets":{"description":"Returns a list of AWS scan targets if the requested scanner is an Amazon Web Services scanner.","method":"GET","uri":"scanners/{scanner_id}/aws-targets","request":{"parameters":{"path":{"scanner_id":{"type":"integer","description":"The id of the scanner.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the AWS target list."},"403":{"description":"Returned if user does not have permission to view scanner data."},"404":{"description":"Returned if the scanner does not exist, or if the scanner is not an AWS scanner."}},"sample":{"data":"representation: scanners.awsTarget"}}},"get-scanner-key":{"description":"Returns the key of the requested scanner.","method":"GET","uri":"scanners/{scanner_id}/key","request":{"parameters":{"path":{"scanner_id":{"type":"integer","description":"The id of the scanner.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the scanner key."},"403":{"description":"Returned if user does not have permission to view scanner data."},"404":{"description":"Returned if the scanner does not exist."}},"sample":{"data":{"key":"string"}}}},"get-scans":{"description":"Returns a list of scans running on the requested scanner.","method":"GET","uri":"scanners/{scanner_id}/scans","request":{"parameters":{"path":{"scanner_id":{"type":"integer","description":"The id of the scanner.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the list of scans runnin gon the requested scanner."},"403":{"description":"Returned if user does not have permission to view scanner data."},"404":{"description":"Returned if the scanner does not exist."}},"sample":{"data":"representation: scanners.scan"}}},"list":{"description":"Returns the scanner list.","method":"GET","uri":"scanners","request":{"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the scanner list."},"403":{"description":"Returned if the user does not have permission to view the list."}},"sample":{"data":{"scanners":["representation: scanners.scanner"]}}}},"toggle-link-state":{"description":"Enables or disables the link state of the scanner identified by 'scanner_id'.","method":"PUT","uri":"scanners/{scanner_id}/link","request":{"parameters":{"path":{"scanner_id":{"type":"integer","description":"The id of the scanner.","required":true}},"payload":{"link":{"type":"integer","description":"Pass 1 enable the link. Pass 0 to disable.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if updating the scanner was successful."},"403":{"description":"Returned if the scanner is a cloud scanner and the user doesn’t have permission to edit it."}}}}}},"scans":{"name":"scans","description":"","representations":[{"name":"scan","description":"The details of a scan.","parameters":{"id":{"type":"integer","description":"The unique id of the scan."},"uuid":{"type":"string","description":"The uuid for the scan."},"name":{"type":"string","description":"The name of the scan."},"type":{"type":"string","description":"The type of scan (local, remote, or agent)."},"owner":{"type":"string","description":"The owner of the scan."},"folder_id":{"type":"integer","description":"The unique id of the folder housing the scan (only returned when folder_id is not in the list request)."},"read":{"type":"boolean","description":"If true, the scan has been read."},"status":{"type":"string","description":"The status of the scan (completed, aborted, imported, killing, pending, running, resuming, canceling, cancelled, pausing, paused, stopping, stopped)."},"shared":{"type":"boolean","description":"If true, the scan is shared."},"user_permissions":{"type":"integer","description":"The sharing permissions for the scan."},"creation_date":{"type":"integer","description":"The creation date for the scan in unixtime."},"last_modification_date":{"type":"integer","description":"The last modification date for the scan in unixtime."},"control":{"type":"boolean","description":"If true, the scan has a schedule and can be launched."},"enabled":{"type":"boolean","description":"If true, the schedule for the scan is enabled."},"starttime":{"type":"string","description":"The scheduled start time for the scan."},"timezone":{"type":"string","description":"The timezone for the scan."},"rrules":{"type":"string","description":"The rules for repeating the scan."}}},{"name":"host","description":"The details of a host.","parameters":{"host_id":{"type":"integer","description":"The unique id of the host."},"host_index":{"type":"string","description":"The index for the host."},"hostname":{"type":"string","description":"The name of the host."},"progress":{"type":"string","description":"The scan progress of the host."},"severity":{"type":"integer","description":"The overall severity rating of the host."},"critical":{"type":"integer","description":"The percentage of critical findings on the host."},"high":{"type":"integer","description":"The percentage of high findings on the host."},"medium":{"type":"integer","description":"The percentage of medium findings on the host."},"low":{"type":"integer","description":"The percentage of low findings on the host."},"info":{"type":"integer","description":"The percentage of info findings on the host."},"totalchecksconsidered":{"type":"integer","description":"The total number of checks considered on the host."},"numchecksconsidered":{"type":"integer","description":"The number of checks processed on the host."},"scanprogresstotal":{"type":"integer","description":"The total scan progress for the host (percentage)."},"scanprogresscurrent":{"type":"integer","description":"The current scan progress for the host (percentage)."},"score":{"type":"integer","description":"The overall score for the host."}}},{"name":"note","description":"Specific information related to the outcome of the scan.","parameters":{"title":{"type":"string","description":"The title of the note."},"message":{"type":"string","description":"The specific message of the note."},"severity":{"type":"integer","description":"The severity of the note."}}},{"name":"remediation","description":"Remedy to vulnerabilites found during the scan.","parameters":{"value":{"type":"string","description":"The unique id of the remediation."},"remediation":{"type":"string","description":"Specific information related to the vulnerability and steps to remedy."},"hosts":{"type":"integer","description":"The number of hosts affected."},"vulns":{"type":"integer","description":"The number of vulnerabilities associated with the remedy."}}},{"name":"history","description":"Historical results from the current scan.","parameters":{"history_id":{"type":"integer","description":"The unique id of the historical data."},"uuid":{"type":"string","description":"The uuid of the historical data."},"owner_id":{"type":"integer","description":"The unique id of the owner of the scan."},"status":{"type":"string","description":"The status of the historical data."},"creation_date":{"type":"integer","description":"The creation date for the historical data in unixtime."},"last_modification_date":{"type":"integer","description":"The last modification date for the historical data in unixtime."}}},{"name":"vulnerability","description":"General vulnerability info.","parameters":{"plugin_id":{"type":"integer","description":"The unique id of the vulnerability plugin."},"plugin_name":{"type":"string","description":"The name of the vulnerability plugin."},"plugin_family":{"type":"string","description":"The parent family of the vulnerability plugin."},"count":{"type":"integer","description":"The number of vulnerabilities found."},"vuln_index":{"type":"integer","description":"The index of the vulnerability plugin."},"severity_index":{"type":"integer","description":"The severity index order of the plugin."}}},{"name":"host_vulnerability","description":"Host vulnerability info.","parameters":{"host_id":{"type":"integer","description":"The unique id of the host."},"hostname":{"type":"string","description":"The name of the host."},"plugin_id":{"type":"integer","description":"The unique id of the vulnerability plugin."},"plugin_name":{"type":"string","description":"The name of the vulnerability plugin."},"plugin_family":{"type":"string","description":"The parent family of the vulnerability plugin."},"count":{"type":"integer","description":"The number of vulnerabilities found."},"vuln_index":{"type":"integer","description":"The index of the vulnerability plugin."},"severity_index":{"type":"integer","description":"The severity index order of the plugin."},"severity":{"type":"integer","description":"The severity of plugin."}}},{"name":"host_compliance","description":"Host compliance info.","parameters":{"host_id":{"type":"integer","description":"The unique id of the host."},"hostname":{"type":"string","description":"The name of the host."},"plugin_id":{"type":"integer","description":"The unique id of the vulnerability plugin."},"plugin_name":{"type":"string","description":"The name of the vulnerability plugin."},"plugin_family":{"type":"string","description":"The parent family of the vulnerability plugin."},"count":{"type":"integer","description":"The number of vulnerabilities found."},"severity_index":{"type":"integer","description":"The severity index order of the plugin."},"severity":{"type":"integer","description":"The severity of plugin."}}},{"name":"plugin_output","description":"Plugin output.","parameters":{"plugin_output":{"type":"string","description":"The text of the plugin output."},"hosts":{"type":"string","description":"Other hosts with the same output."},"severity":{"type":"integer","description":"The severity the output."},"ports":{"type":"object","description":"An object containing ports and hostnames"}}},{"name":"filter","description":"Filter used to search and sort scan details.","parameters":{"name":{"type":"string","description":"The short name of the filter."},"readable_name":{"type":"string","description":"The long name of the filter."},"operators":{"type":"array","description":"The comparison options for the filter."},"control":{"type":"object","description":"The input type, placeholder, and regex values for the filter.","parameters":{"type":{"type":"string","description":"The input type (entry or dropdown)."},"readable_regest":{"type":"string","description":"The placeholder for the input."},"regex":{"type":"string","description":"A regex for checking the value of the input."},"options":{"type":"array","description":"A list of options if the input is a dropdown."}}}}},{"name":"timezone","description":"Timezones are used to ensure scans run at the proper local time.","parameters":{"name":{"type":"string","description":"The readable name of the timezone."},"value":{"type":"string","description":"The system value for the timezone."}}},{"name":"scan_compliance_counts","description":"Tally of the compliance findings by category for a scan.","parameters":{"total":{"type":"integer","description":"Total number of compliance issues found in the scan."},"pass":{"type":"integer","description":"Number of compliance issues found in the scan with a passing status."},"warn":{"type":"integer","description":"Number of compliance issues found in the scan with a warn status."},"fail":{"type":"integer","description":"Number of compliance issues found in the scan with a fail status."}}},{"name":"scan_compliance_counts_history","description":"Tally of the compliance findings by category for a scan.","parameters":{"total":{"type":"integer","description":"Total number of compliance issues found in the scan."},"pass":{"type":"integer","description":"Number of compliance issues found in the scan with a passing status."},"warn":{"type":"integer","description":"Number of compliance issues found in the scan with a warn status."},"fail":{"type":"integer","description":"Number of compliance issues found in the scan with a fail status."},"report_date":{"type":"integer","description":"The data and time in milliseconds from the epoc that represents when the scan finished."}}},{"name":"scan_vulnerability_counts","description":"Tally of the vulnerability findings by category for a scan.","parameters":{"total":{"type":"integer","description":"Total number of vulnerability issues found in the scan."},"info":{"type":"integer","description":"Number of vulnerability issues found in the scan with a info severity."},"low":{"type":"integer","description":"Number of vulnerability issues found in the scan with a low severity."},"med":{"type":"integer","description":"Number of vulnerability issues found in the scan with a med severity."},"high":{"type":"integer","description":"Number of vulnerability issues found in the scan with a high severity."},"critical":{"type":"integer","description":"Number of vulnerability issues found in the scan with a critical severity."}}},{"name":"scan_vulnerability_counts_history","description":"Tally of the vulnerability findings by category for a scan.","parameters":{"total":{"type":"integer","description":"Total number of vulnerability issues found in the scan."},"info":{"type":"integer","description":"Number of vulnerability issues found in the scan with a info severity."},"low":{"type":"integer","description":"Number of vulnerability issues found in the scan with a low severity."},"med":{"type":"integer","description":"Number of vulnerability issues found in the scan with a med severity."},"high":{"type":"integer","description":"Number of vulnerability issues found in the scan with a high severity."},"critical":{"type":"integer","description":"Number of vulnerability issues found in the scan with a critical severity."},"report_date":{"type":"integer","description":"The data and time in milliseconds from the epoc that represents when the scan finished."}}}],"methods":{"attachment-prepare":{"description":"Returns a single-use scan attachment token for the scan and attachment IDs.","method":"POST","uri":"scans/{scan_id}/attachments/{attachment_id}/prepare","request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan containing the attachment.","required":true},"attachment_id":{"type":"integer","description":"The id of the scan attachment.","required":true}},"payload":{"history_id":{"type":"integer","description":"The scan history ID...if not provided, will default to most recent.","required":false}}},"permissions":{"type":"scan","value":64}},"response":{"codes":{"200":{"description":"Returns the 64-character single-use attachment token."},"404":{"description":"Returned if the attachment token cannot be prepared."}}}},"configure":{"description":"Changes the schedule or policy parameters of a scan.","method":"PUT","manager_only":true,"uri":"scans/{scan_id}","no_test":true,"request":{"description":"These parameters are the minimum required when configuring a scan that uses an existing policy. If the scan uses an editor template, all fields returned from <a href=\"#/resources/editor/edit\">editor: edit</a> must be sent in addition to these parameters. A sample request body is provided below.","parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to change.","required":true}},"payload":{"uuid":{"type":"string","description":"The uuid for the editor template to use.","required":false},"settings":{"name":"settings","object":true,"inputs":{"name":{"type":"string","description":"The name of the scan.","required":true},"description":{"type":"string","description":"The description of the scan.","required":false},"policy_id":{"type":"integer","description":"The unique id of the policy to use.","required":false},"folder_id":{"type":"integer","description":"The unique id of the destination folder for the scan.","required":false},"scanner_id":{"type":"integer","description":"The unique id of the scanner to use.","required":false,"placeholder":"1"},"enabled":{"type":"boolean","description":"If true, the schedule for the scan is enabled.","required":true},"launch":{"type":"string","description":"When to launch the scan. (i.e. DAILY, WEEKLY, MONTHLY, YEARLY)","required":false,"dropdown":true,"options":["DAILY","WEEKLY","MONTHLY","YEARLY"]},"starttime":{"type":"string","description":"The starting time and date for the scan (i.e. YYYYMMDDTHHMMSS).","required":false,"placeholder":"20140826T133000"},"rrules":{"type":"string","description":"Expects a semi-colon delimited string comprised of three values. The frequency (FREQ=ONETIME or DAILY or WEEKLY or MONTHLY or YEARLY), the interval (INTERVAL=1 or 2 or 3 ... x), and the days of the week (BYDAY=SU,MO,TU,WE,TH,FR,SA). To create a scan that runs every three weeks on Monday Wednesday and Friday the string would be 'FREQ=WEEKLY;INTERVAL=3;BYDAY=MO,WE,FR'","required":false,"placeholder":"FREQ=DAILY;INTERVAL=1"},"timezone":{"type":"string","description":"The timezone for the scan schedule.","required":false,"placeholder":"America/New_York"},"target_groups":{"type":"array","description":"An array of target group IDs to scan.","required":false,"placeholder":"[2, 8, 12]"},"agent_groups":{"type":"array","description":"An array of agent group IDs to scan.  Required if the scan is an agent scan..","required":false,"placeholder":"[37, 83, 24]"},"text_targets":{"type":"string","description":"Comma separated list of targets to scan.  Required for non-agent scans if no target groups are provided.","required":true,"placeholder":"localhost"},"file_targets":{"type":"string","description":"The name of a file containing the list of targets to scan.","required":false,"placeholder":"targets.txt"},"emails":{"type":"string","description":"A comma separated list of accounts who will recieve the email summary report.","required":false,"placeholder":"test1@test.com, test2@test.com"},"acls":{"type":"array","description":"An array containing permissions to apply to the scan.","required":false,"placeholder":"[{\"type\": \"default\", \"permissions\": 16}, {\"type\": \"user\", \"permissions\": 64, \"name\": \"admin\", \"id\": 1, \"owner\": 1}]"}}}}},"permissions":{"type":"scan","value":64},"sample":{"data":{"uuid":"var:template_uuid","settings":{"name":"string","description":"string","emails":"string","enabled":"boolean","launch":"string","folder_id":"integer","policy_id":"integer","scanner_id":"integer","text_targets":"string"}}}},"response":{"codes":{"200":{"description":"Returned if the configuration was changed."},"404":{"description":"Returned if the scan does not exist."},"500":{"description":"Returned if an error occurred while saving the configuration."}},"sample":{"data":{"creation_date":"integer","custom_targets":"string","default_permisssions":"integer","description":"string","emails":"string","id":"integer","last_modification_date":"integer","name":"string","notification_filter_type":"string","notification_filters":"string","owner":"string","owner_id":"integer","policy_id":"integer","rrules":"string","scanner_id":"integer","shared":"integer","starttime":"string","tag_id":"integer","timezone":"string","type":"string","user_permissions":"integer","uuid":"string"}}}},"copy":{"description":"Copies the given scan.","method":"POST","uri":"scans/{scan_id}/copy","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to export.","required":true}},"payload":{"folder_id":{"type":"integer","description":"The id of the destination folder."},"name":{"type":"string","description":"The name of the copied scan."}}},"permissions":{"type":"scan","value":64}},"response":{"codes":{"200":{"description":"Returns the copied scan object."},"404":{"description":"Returned if the scan does not exist."},"500":{"description":"Returned if an error occurred while copying."}},"sample":{"data":"representation: scans.scan"}}},"create":{"description":"Create a scan.","method":"POST","uri":"scans","no_test":true,"manager_only":true,"request":{"description":"These parameters are the minimum required for creating a scan from an existing policy.  If using an editor template, all fields returned from <a href=\"#/resources/editor/details\">editor: details</a> must be sent in addition to these parameters.  A sample request body is provided below.","parameters":{"payload":{"uuid":{"type":"string","description":"The uuid for the editor template to use.","required":true,"placeholder":"ab4bacd2-05f6-425c-9d79-3ba3940ad1c24e51e1f403febe40"},"settings":{"name":"settings","object":true,"inputs":{"name":{"type":"string","description":"The name of the scan.","required":true},"description":{"type":"string","description":"The description of the scan.","required":false},"policy_id":{"type":"integer","description":"The unique id of the policy to use.","required":false},"folder_id":{"type":"integer","description":"The unique id of the destination folder for the scan.","required":false},"scanner_id":{"type":"integer","description":"The unique id of the scanner to use.","required":false,"placeholder":"1"},"enabled":{"type":"boolean","description":"If true, the schedule for the scan is enabled.","required":true},"launch":{"type":"string","description":"When to launch the scan. (i.e. ON_DEMAND, DAILY, WEEKLY, MONTHLY, YEARLY)","required":false,"dropdown":true,"options":["ON_DEMAND","DAILY","WEEKLY","MONTHLY","YEARLY"]},"starttime":{"type":"string","description":"The starting time and date for the scan (i.e. YYYYMMDDTHHMMSS).","required":false,"placeholder":"20140826T133000"},"rrules":{"type":"string","description":"Expects a semi-colon delimited string comprised of three values. The frequency (FREQ=ONETIME or DAILY or WEEKLY or MONTHLY or YEARLY), the interval (INTERVAL=1 or 2 or 3 ... x), and the days of the week (BYDAY=SU,MO,TU,WE,TH,FR,SA). To create a scan that runs every three weeks on Monday Wednesday and Friday the string would be 'FREQ=WEEKLY;INTERVAL=3;BYDAY=MO,WE,FR'","required":false,"placeholder":"FREQ=DAILY;INTERVAL=1"},"timezone":{"type":"string","description":"The timezone for the scan schedule.","required":false,"placeholder":"America/New_York"},"text_targets":{"type":"string","description":"The list of targets to scan.","required":true,"placeholder":"localhost"},"agent_group_id":{"type":"array","description":"The list of agent group IDs to scan; only valid for Agent scans.","required":true,"placeholder":"localhost"},"file_targets":{"type":"string","description":"The name of a file containing the list of targets to scan.","required":false,"placeholder":"targets.txt"},"emails":{"type":"string","description":"A comma separated list of accounts who will recieve the email summary report.","required":false,"placeholder":"test1@test.com, test2@test.com"},"acls":{"type":"array","description":"An array containing permissions to apply to the scan.","required":false,"placeholder":"[{\"type\": \"default\", \"permissions\": 16}, {\"type\": \"user\", \"permissions\": 64, \"name\": \"admin\", \"id\": 1, \"owner\": 1}]"}}}}},"permissions":{"type":"user","value":32},"sample":{"data":{"uuid":"var:template_uuid","settings":{"name":"string","description":"string","emails":"string","enabled":"true","launch":"string","folder_id":"integer","policy_id":"integer","scanner_id":"integer","text_targets":"string","agent_group_id":"array"}}}},"response":{"codes":{"200":{"description":"Returned if the scan was saved successfully."},"500":{"description":"Returned if an error occurred while saving the scan."}},"sample":{"data":{"scan":{"creation_date":"integer","custom_targets":"string","default_permisssions":"integer","description":"string","emails":"string","id":"integer","last_modification_date":"integer","name":"string","notification_filter_type":"string","notification_filters":"string","owner":"string","owner_id":"integer","policy_id":"integer","enabled":"boolean","rrules":"string","scanner_id":"integer","shared":"integer","starttime":"string","tag_id":"integer","timezone":"string","type":"string","user_permissions":"integer","uuid":"string"}}}}},"delete":{"description":"Delete a scan. NOTE: Scans in running, paused or stopping states can not be deleted.","method":"DELETE","uri":"scans/{scan_id}","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to delete.","required":true}}},"permissions":{"type":"scan","value":64}},"response":{"codes":{"200":{"description":"Returned if the scan has been successfully deleted."},"500":{"description":"Returned if the server failed to delete the scan."}}}},"delete-bulk":{"description":"Delete scans in bulk. NOTE: Scans in running, paused or stopping states can not be deleted.","method":"DELETE","uri":"scans","manager_only":true,"request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of scan IDs to delete.","required":true}}},"permissions":{"type":"scan","value":64}},"response":{"codes":{"200":{"description":"Returned if the scans have been successfully deleted."},"400":{"description":"Returned if a field is invalid."},"403":{"description":"Returned if the user does not have permission to delete the scans."},"404":{"description":"Returned if one or more scans does not exist."},"500":{"description":"Returned if the server failed to delete the scans."}},"sample":{"data":{"deleted":"array"}}}},"delete-history":{"description":"Delete historical results from a scan.","method":"DELETE","uri":"scans/{scan_id}/history/{history_id}","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan.","required":true},"history_id":{"type":"integer","description":"The id of the results to delete.","required":true}}},"permissions":{"type":"scan","value":64}},"response":{"codes":{"200":{"description":"Returned if the results were successfully deleted."},"404":{"description":"Returned if the results were not found."},"500":{"description":"Returned if the server failed to delete the results."}}}},"details":{"description":"Returns details for the given scan.","method":"GET","uri":"scans/{scan_id}","request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to retrieve.","required":true}},"query":{"history_id":{"type":"integer","description":"The history_id of the historical data that should be returned."},"limit":{"type":"integer","description":"The maximum number of hosts that should be returned."}}},"permissions":{"type":"scan","value":16}},"response":{"codes":{"200":{"description":"Returns the scan details."}},"sample":{"data":{"info":{"acls":["representation: permissions.permission"],"edit_allowed":"boolean","status":"string","policy":"string","pci-can-upload":"boolean","hasaudittrail":"boolean","scan_start":"string","folder_id":"integer","targets":"string","timestamp":"integer","object_id":"integer","scanner_name":"string","haskb":"boolean","uuid":"string","hostcount":"integer","scan_end":"string","name":"string","user_permissions":"integer","control":"boolean"},"hosts":["representation: scans.host"],"comphosts":["representation: scans.host"],"notes":["representation: scans.note"],"remediations":{"remediations":["representation: scans.remediation"],"num_hosts":"integer","num_cves":"integer","num_impacted_hosts":"integer","num_remediated_cves":"integer"},"vulnerabilities":["representation: scans.vulnerability"],"compliance":["representation: scans.vulnerability"],"history":["representation: scans.history"],"filters":["representation: scans.filter"]}}}},"details-filters":{"private":true,"description":"Returns the filters available for scan details.","method":"GET","uri":"filters/scans/reports","manager_only":true,"request":{"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the filters object."}},"sample":{"data":{"filters":["representation: scans.filter"]}}}},"export-formats":{"description":"Returns available export formats and report options.","method":"GET","uri":"scans/{scan_id}/export/formats","request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The ID of the scan to export.","required":true}},"query":{"schedule_id":{"type":"integer","description":"The ID for the schedule that the scan is associated with.","required":false}}},"permissions":{"type":"scan","value":16}},"response":{"codes":{"200":{"description":"Returns available export and report formatting options."},"404":{"description":"Returns if the scan does not exist."}},"sample":{"data":{"report_options":{"formattingOptions":[{"name":"Page Breaks","key":"page_breaks"}],"csvColumns":[{"isDefault":true,"key":"id","name":"Plugin ID"},{"name":"CVE","key":"cve","isDefault":true},{"name":"Plugin ID","key":"id","isDefault":true},{"name":"CVE","key":"cve","isDefault":true},{"name":"CVSS v2.0 Base Score","key":"cvss","isDefault":true},{"name":"Risk","key":"risk","isDefault":true},{"name":"Host","key":"hostname","isDefault":true},{"name":"Protocol","key":"protocol","isDefault":true},{"name":"Port","key":"port","isDefault":true},{"name":"Name","key":"plugin_name","isDefault":true},{"name":"Synopsis","key":"synopsis","isDefault":true},{"name":"Description","key":"description","isDefault":true},{"name":"Solution","key":"solution","isDefault":true},{"name":"See Also","key":"see_also","isDefault":true},{"name":"Plugin Output","key":"plugin_output","isDefault":true},{"name":"STIG Severity","key":"stig_severity","isDefault":false},{"name":"CVSS v3.0 Base Score","key":"cvss3_base_score","isDefault":false},{"name":"CVSS v2.0 Temporal Score","key":"cvss_temporal_score","isDefault":false},{"name":"CVSS v3.0 Temporal Score","key":"cvss3_temporal_score","isDefault":false},{"name":"Risk Factor","key":"risk_factor","isDefault":false},{"name":"References","detailColumns":[{"name":"BID","key":"bid"},{"name":"XREF","key":"xref"},{"name":"MSKB","key":"mskb"}],"key":"references","isDefault":false},{"name":"Plugin Information","detailColumns":[{"name":"Plugin Publication Date","key":"plugin_publication_date"},{"name":"Plugin Modification Date","key":"plugin_modification_date"}],"key":"plugin_information","isDefault":false},{"name":"Exploitable With","detailColumns":[{"name":"Metasploit","key":"exploit_framework_metasploit"},{"name":"Core Impact","key":"exploit_framework_core"},{"name":"CANVAS","key":"exploit_framework_canvas"}],"key":"exploitable_with","isDefault":false}]},"formats":{"custom":[],"export":[{"name":"Nessus","value":"nessus"},{"name":"Nessus DB","value":"db"}],"format":[{"name":"PDF","value":"pdf"},{"name":"HTML","value":"html"},{"name":"CSV","value":"csv"}]}}}}},"export-download":{"description":"Download an exported scan.","method":"DOWNLOAD","uri":"scans/{scan_id}/export/{file_id}/download","request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to export.","required":true},"file_id":{"type":"integer","description":"The id of the file to download (Included in response from /scans/{scan_id}/export).","required":true}}},"permissions":{"type":"scan","value":16}},"response":{"codes":{"200":{"description":"Returns the content of the file as an attachment."},"404":{"description":"Returned if the file does not exist."}}}},"export-request":{"description":"Export the given scan. Once requested, the file can be downloaded using the <a href=\"#/resources/tokens/download\">token download</a> method upon receiving a \"ready\" status from the <a href=\"#/resources/tokens/status\">token status</a> method.  You can also use the older <a href=\"#/resources/scans/export-status\">export status</a> and <a href=\"#/resources/scans/export-download\">export download</a> methods.<br>NOTE: In cluster environments, Tenable.sc is the aggregation point for scan data, not the cluster parent node.  The cluster nodes are not intended to have export requests made of them.<br>","method":"POST","uri":"scans/{scan_id}/export","request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to export.","required":true}},"payload":{"format":{"type":"string","description":"The file format to use (Nessus, HTML, PDF, CSV, or DB).","required":true,"dropdown":true,"options":["nessus","html","pdf","csv","db"]},"password":{"type":"string","description":"The password used to encrypt database exports (*Required when exporting as DB).","required":false,"masked":true},"chapters":{"type":"string","description":"[DEPRECATED] The chapters to include in the export (expecting a semi-colon delimited string comprised of some combination of the following options: vuln_hosts_summary, vuln_by_host, compliance_exec, remediations, vuln_by_plugin, compliance)","required":false},"filters":{"type":"object","description":"An object containing filters to apply to the exported scan report.","required":false,"placeholder":"{\"filter.0.quality\": \"cvss_base_score\", \"filter.0.quality\": \"gt\", \"filter.0.value\": \"2\", \"filter.1.quality\": \"date-gt\", \"filter.1.filter\": \"plugin_modification_date\", \"filter.1.value\": \"2011-02-01\"}"},"filter.search_type":{"type":"string","description":"The type of search to be used.","required":false,"dropdown":true,"options":["and","or"]},"reportContents.formattingOptions.page_breaks":{"type":"boolean","description":"[DEPRECATED] if true, separates vulnerabilities grouped by (Host, Plugins) with page breaks.","required":false},"reportContents.hostSections.scan_information":{"type":"boolean","description":"[DEPRECATED] if true, Scan Information is included in report.","required":false},"reportContents.hostSections.host_information":{"type":"boolean","description":"[DEPRECATED] if true, Host Information is included in report.","required":false},"reportContents.vulnerabilitySections.synopsis":{"type":"boolean","description":"[DEPRECATED] if true, Synopsis is included in report. * If Available.","required":false},"reportContents.vulnerabilitySections.description":{"type":"boolean","description":"[DEPRECATED] if true, Description is included in report.","required":false},"reportContents.vulnerabilitySections.see_also":{"type":"boolean","description":"[DEPRECATED] if true, See Also is included in report.","required":false},"reportContents.vulnerabilitySections.solution":{"type":"boolean","description":"[DEPRECATED] if true, Solution is included in report.","required":false},"reportContents.vulnerabilitySections.risk_factor":{"type":"boolean","description":"[DEPRECATED] if true, Risk Factor is included in report.","required":false},"reportContents.vulnerabilitySections.cvss3_base_score":{"type":"boolean","description":"[DEPRECATED] if true, CVSS v3.0 Base Score is included in report.","required":false},"reportContents.vulnerabilitySections.cvss3_temporal_score":{"type":"boolean","description":"[DEPRECATED] if true, CVSS v3.0 Temporal Score is included in report.","required":false},"reportContents.vulnerabilitySections.cvss_base_score":{"type":"boolean","description":"[DEPRECATED] if true, CVSS Base Score is included in report.","required":false},"reportContents.vulnerabilitySections.cvss_temporal_score":{"type":"boolean","description":"[DEPRECATED] if true, CVSS Temporal Score is included in report.","required":false},"reportContents.vulnerabilitySections.stig_severity":{"type":"boolean","description":"[DEPRECATED] if true, STIG Severity is included in report.","required":false},"reportContents.vulnerabilitySections.references":{"type":"boolean","description":"[DEPRECATED] if true, References are included in report.","required":false},"reportContents.vulnerabilitySections.exploitable_with":{"type":"boolean","description":"[DEPRECATED] if true, Exploitable With is included in report.","required":false},"reportContents.vulnerabilitySections.plugin_information":{"type":"boolean","description":"[DEPRECATED] if true, Plugin Information is included in report.","required":false},"reportContents.vulnerabilitySections.plugin_output":{"type":"boolean","description":"[DEPRECATED] if true, Plugin Output is included in report.","required":false},"template_id":{"type":"boolean","description":"The id of the report remplate to be used.","required":true}},"query":{"history_id":{"type":"integer","description":"The history_id of the historical data that should be exported.","required":false}}},"filters":{"scans":true,"list":[{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9]+$"},"name":"plugin.attributes.bid","readable_name":"Bugtraq ID"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9]+$"},"name":"xref:CERT","readable_name":"CERT Vulnerability ID"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":".*"},"name":"plugin.attributes.cpe","readable_name":"CPE"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"CVE-YYYY-ID","type":"entry","regex":"^(CVE|CAN)-(1999|20[01][0-9])-[0-9]{4,}$"},"name":"plugin.attributes.cve.raw","readable_name":"CVE"},{"operators":["lt","gt","eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9]+(\\.[0-9]+)?$"},"name":"plugin.attributes.cvss3_base_score","readable_name":"CVSS v3.0 Base Score"},{"operators":["lt","gt","eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9]+(\\.[0-9]+)$"},"name":"plugin.attributes.cvss3_temporal_score","readable_name":"CVSS v3.0 Temporal Score"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":"^CVSS:3.0/E:(U|POC|F|H|ND)/RL:(OF|T|W|U|ND)/RC:(UC|UR|C|ND)$"},"name":"plugin.attributes.cvss3_temporal_vector.raw","readable_name":"CVSS v3.0 Temporal Vector"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":"^CVSS:3.0/AV:(N|A|L|P)/AC:(L|H)/PR:(N,L,H)/UI:(N|R)/S:(U|C)/C:(H|L|N)/I:(H|L|N)/A:(H|L|N)$"},"name":"plugin.attributes.cvss3_vector.raw","readable_name":"CVSS v3.0 Vector"},{"operators":["lt","gt","eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9]+(\\.[0-9]+)?$"},"name":"plugin.attributes.cvss_base_score","readable_name":"CVSS Base Score"},{"operators":["lt","gt","eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9]+(\\.[0-9]+)$"},"name":"plugin.attributes.cvss_temporal_score","readable_name":"CVSS Temporal Score"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":"^CVSS2#E:(U|POC|F|H|ND)/RL:(OF|T|W|U|ND)/RC:(UC|UR|C|ND)$"},"name":"plugin.attributes.cvss_temporal_vector.raw","readable_name":"CVSS Temporal Vector"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":"^CVSS2#AV:(L|A|N)/AC:(H|M|L)/Au:(N|S|M)/C:(N|P|C)/I:(N|P|C)/A:(N|P|C)$"},"name":"plugin.attributes.cvss_vector.raw","readable_name":"CVSS Vector"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^([0-9]+)$"},"name":"xref:CWE","readable_name":"CWE"},{"operators":["match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":".*"},"name":"plugin.attributes.description","readable_name":"Plugin Description"},{"operators":["eq","neq"],"control":{"type":"dropdown","list":["true","false"]},"name":"plugin.attributes.exploit_available","readable_name":"Exploit Available"},{"operators":["eq","neq"],"control":{"type":"dropdown","list":["Exploits are available","No exploit is required","No known exploits are available"]},"name":"plugin.attributes.exploitability_ease.raw","readable_name":"Exploitability Ease"},{"operators":["eq","neq"],"control":{"type":"dropdown","list":["true","false"]},"name":"plugin.attributes.exploited_by_malware","readable_name":"Exploited By Malware"},{"operators":["eq","neq"],"control":{"type":"dropdown","list":["true","false"]},"name":"plugin.attributes.exploited_by_nessus","readable_name":"Exploited By Nessus"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":".*"},"name":"host.hostname","readable_name":"Hostname"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"YYYY-A-ID","type":"entry","regex":"^[0-9]+-[A-Za-z]-[0-9]+$"},"name":"xref:IAVA","readable_name":"IAVA ID"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"YYYY-B-ID","type":"entry","regex":"^[0-9]+-[A-Za-z]-[0-9]+$"},"name":"xref:IAVB","readable_name":"IAVB ID"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"YYYY-A-ID","type":"entry","regex":"^[0-9]+-[A-Za-z]-[0-9]+$"},"name":"xref:IAVT","readable_name":"IAVT ID"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9, ]+$"},"name":"plugin.id","readable_name":"Plugin ID"},{"operators":["eq","neq"],"control":{"type":"dropdown","list":["true","false"]},"name":"plugin.attributes.in_the_news","readable_name":"In The News"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"MS0X-YZT","type":"entry","regex":"^MS[0-9]+-[0-9]+$"},"name":"xref:MSFT","readable_name":"Microsoft Bulletin"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":".*"},"name":"plugin.name","readable_name":"Plugin Name"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9]+$"},"name":"xref:OSVDB","readable_name":"OSVDB ID"},{"operators":["date-lt","date-gt","date-eq","date-neq","match","nmatch"],"control":{"type":"datefield","readable_regex":"MM/DD/YYYY"},"name":"plugin.attributes.patch_publication_date","readable_name":"Patch Publication Date"},{"operators":["eq","neq"],"control":{"type":"dropdown","list":["family1","...","familyN"]},"name":"plugin.family","readable_name":"Plugin Family"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9, ]+$"},"name":"plugin.id","readable_name":"Plugin ID"},{"operators":["date-lt","date-gt","date-eq","date-neq","match","nmatch"],"control":{"type":"datefield","readable_regex":"MM/DD/YYYY"},"name":"plugin.attributes.plugin_modification_date","readable_name":"Plugin Modification Date"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":".*"},"name":"plugin.name","readable_name":"Plugin Name"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":".*"},"name":"output","readable_name":"Plugin Output"},{"operators":["date-lt","date-gt","date-eq","date-neq","match","nmatch"],"control":{"type":"datefield","readable_regex":"MM/DD/YYYY"},"name":"plugin.attributes.plugin_publication_date","readable_name":"Plugin Publication Date"},{"operators":["eq","neq"],"control":{"type":"dropdown","list":["local","remote"]},"name":"plugin.attributes.plugin_type","readable_name":"Plugin Type"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"NUMBER","type":"entry","regex":"^[0-9]+$"},"name":"port.port","readable_name":"Port"},{"operators":["eq","neq"],"control":{"type":"dropdown","list":["tcp","udp","icmp"]},"name":"port.protocol","readable_name":"Protocol"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":".*"},"name":"plugin.attributes.see_also","readable_name":"See Also"},{"operators":["eq","neq"],"control":{"type":"dropdown","list":["0","1","2","3","4"]},"name":"severity","readable_name":"Severity"},{"operators":["match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":".*"},"name":"plugin.attributes.solution","readable_name":"Solution"},{"operators":["eq","neq","match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":"^[ivIV]+"},"name":"plugin.attributes.stig_severity","readable_name":"IAVM Severity"},{"operators":["match","nmatch"],"control":{"readable_regex":"TEXT","type":"entry","regex":".*"},"name":"plugin.attributes.synopsis","readable_name":"Synopsis"},{"operators":["date-lt","date-gt","date-eq","date-neq","match","nmatch"],"control":{"type":"datefield","readable_regex":"MM/DD/YYYY"},"name":"plugin.attributes.vuln_publication_date","readable_name":"Vulnerability Publication Date"}]},"permissions":{"type":"scan","value":16}},"response":{"codes":{"200":{"description":"Returned if the export was queued successfully."},"400":{"description":"Returned if a required parameter is missing."},"404":{"description":"Returned if the scan does not exist."},"409":{"description":"Returned if the scan is still active or in the middle of creating the report already."}},"sample":{"data":{"file":"integer","token":"string"}}}},"export-status":{"description":"Check the file status of an exported scan. When an export has been requested, it is necessary to poll this endpoint until a \"ready\" status is returned, at which point the file is complete and can be downloaded using the <a href=\"#/resources/scans/export-download\">export download</a> endpoint.","method":"GET","uri":"scans/{scan_id}/export/{file_id}/status","request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to export.","required":true},"file_id":{"type":"integer","description":"The id of the file to poll (Included in response from /scans/{scan_id}/export).","required":true}}},"permissions":{"type":"scan","value":16}},"response":{"codes":{"200":{"description":"Returns the status of the file. A status of \"ready\" indicates the file can be downloaded."},"404":{"description":"Returned if the file does not exist."}},"sample":{"data":{"status":"string"}}}},"host-details":{"description":"Returns details for the given host.","method":"GET","uri":"scans/{scan_id}/hosts/{host_id}","request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to retrieve.","required":true},"host_id":{"type":"integer","description":"The id of the host to retrieve.","required":true}},"query":{"history_id":{"type":"integer","description":"The history_id of the historical data that should be returned."}}},"permissions":{"type":"scan","value":16}},"response":{"codes":{"200":{"description":"Returns the host details."}},"sample":{"data":{"info":{"host_start":"string","mac-address":"string","host-fqdn":"string","host_end":"string","operating-system":"string","host-ip":"string"},"compliance":["representation: scans.host_compliance"],"vulnerabilities":["representation: scans.host_vulnerability"]}}}},"import":{"description":"Import an existing scan uploaded using <a href=\"#/resources/file/upload\">file: upload</a>.","method":"POST","uri":"scans/import","manager_only":true,"request":{"parameters":{"payload":{"file":{"type":"string","description":"The name of the file to import as provided by the response from <a href=\"#/resources/file/upload\">file: upload</a>.","required":true},"folder_id":{"type":"integer","description":"The id of the destination folder.  If not specified, the default folder will be used.","required":false},"password":{"type":"string","description":"The password for the file to import (required for nessus.db).","required":false,"masked":true}}},"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the scan object."},"500":{"description":"Returned if the server failed to import the scan."}}}},"kill":{"description":"For use on scans from the local scanner only, \"kill\" terminates a scan faster than \"stop\".  All in-progress plugins are terminated.  A scan can be killed with the scan in any state.","method":"POST","uri":"scans/{scan_id}/kill","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to kill.","required":true}}},"permissions":{"type":"scan","value":32}},"response":{"codes":{"200":{"description":"Returned if the scan was successfully queued to be killed."},"403":{"description":"Returned if an attempt was made to kill a remote scan."},"404":{"description":"Returned if the scan does not exist."},"409":{"description":"Returned if the scan is not active."}}}},"launch":{"description":"Launches a scan.","method":"POST","uri":"scans/{scan_id}/launch","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to launch.","required":true}},"payload":{"alt_targets":{"type":"array","description":"If specified, these targets will be scanned instead of the default. Value can be an array where each index is a target, or an array with a single index of comma separated targets."}}},"permissions":{"type":"scan","value":32}},"response":{"codes":{"200":{"description":"Returned if the scan was successfully launched."},"403":{"description":"Returned if the scan is disabled."},"404":{"description":"Returned if the scan does not exist."}},"sample":{"data":{"scan_uuid":"string"}}}},"list":{"description":"Returns the scan list.","method":"GET","uri":"scans","request":{"parameters":{"payload":{"folder_id":{"type":"integer","description":"The id of the folder whose scans should be listed."},"last_modification_date":{"type":"integer","description":"Limit the results to those that have only changed since this time."}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the scan list."}},"sample":{"data":{"folders":["representation: folders.folder"],"scans":["representation: scans.scan"],"timestamp":"integer"}}}},"pause":{"description":"Pauses a scan.","method":"POST","uri":"scans/{scan_id}/pause","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to pause.","required":true}}},"permissions":{"type":"scan","value":32}},"response":{"codes":{"200":{"description":"Returned if the scan was successfully queued to pause."},"404":{"description":"Returned if the scan does not exist."},"409":{"description":"Returned if the scan is not active."}}}},"plugin-output":{"description":"Returns the output for a given plugin.","method":"GET","uri":"scans/{scan_id}/hosts/{host_id}/plugins/{plugin_id}","request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to retrieve.","required":true},"host_id":{"type":"integer","description":"The id of the host to retrieve.","required":true},"plugin_id":{"type":"integer","description":"The id of the plugin to retrieve.","required":true}},"query":{"history_id":{"type":"integer","description":"The history_id of the historical data that should be returned."}}},"permissions":{"type":"scan","value":16}},"response":{"codes":{"200":{"description":"Returns the plugin output."}},"sample":{"data":{"info":{"plugindescription":{"severity":"integer","pluginname":"string","pluginattributes":{"risk_information":{"risk_factor":"string"},"plugin_name":"string","plugin_information":{"plugin_id":"integer","plugin_type":"string","plugin_family":"string","plugin_modification_date":"string"},"solution":"string","fname":"string","synopsis":"string","description":"string"},"pluginfamily":"string","pluginid":"integer"}},"output":["representation: scans.plugin_output"]}}}},"read-status":{"description":"Changes the status of a scan.","method":"PUT","uri":"scans/{scan_id}/status","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to change.","required":true}},"payload":{"read":{"type":"boolean","description":"If true, the scan has been read.","required":true}}},"permissions":{"type":"scan","value":16}},"response":{"codes":{"200":{"description":"Returned if the status was changed."},"404":{"description":"Returned if the scan does not exist."}}}},"resume":{"description":"Resumes a scan.","method":"POST","uri":"scans/{scan_id}/resume","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to resume.","required":true}}},"permissions":{"type":"scan","value":32}},"response":{"codes":{"200":{"description":"Returned if the scan was successfully queued to resume."},"404":{"description":"Returned if the scan does not exist."},"409":{"description":"Returned if the scan is not active."}}}},"schedule":{"description":"Enables or disables a scan schedule.","method":"PUT","uri":"scans/{scan_id}/schedule","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan.","required":true}},"payload":{"enabled":{"type":"boolean","description":"Enables or disables the scan schedule.","required":true}}},"permissions":{"type":"scan","value":32}},"response":{"codes":{"200":{"description":"Returned if the scan schedule was enabled or disabled."},"404":{"description":"Returned if the scan does not exist."},"500":{"description":"Returned if the scan does not have a schedule to enable."}},"sample":{"data":{"enabled":true,"control":true,"rrules":"string","starttime":"string","timezone":"string"}}}},"stop":{"description":"Stops a scan.","method":"POST","uri":"scans/{scan_id}/stop","manager_only":true,"request":{"parameters":{"path":{"scan_id":{"type":"integer","description":"The id of the scan to stop.","required":true}}},"permissions":{"type":"scan","value":32}},"response":{"codes":{"200":{"description":"Returned if the scan was successfully queued to stop."},"404":{"description":"Returned if the scan does not exist."},"409":{"description":"Returned if the scan is not active."}}}},"timezones":{"description":"Returns the timezone list for creating a scan.","method":"GET","uri":"scans/timezones","manager_only":true,"request":{"permissions":{"type":"user","value":32}},"response":{"codes":{"200":{"description":"Returns the timezone list."},"403":{"description":"Returned if the user does not have permission to view timezones."}},"sample":{"data":{"timezones":["representation: scans.timezone"]}}}}}},"server":{"name":"server","description":"","methods":{"properties":{"description":"Returns the server version and other properties. Nessus build and version numbers are only available with an established session.","method":"GET","uri":"server/properties","response":{"codes":{"200":{"description":"Returns the server properties."}},"sample":{"data":{"capabilities":{"multi_scanner":"boolean","multi_user":"string","report_email_config":"boolean"},"enterprise":"boolean","expiration":"integer","expiration_time":"integer","idle_timeout":"integer","license":{"agents":"integer","expiration_date":"string","ips":"integer","scanners":"integer"},"loaded_plugin_set":"string","login_banner":"boolean","nessus_type":"string","nessus_ui_version":"string","notifications":[{"type":"string","message":"string"}],"plugin_set":"string","scanner_boottime":"integer","server_version":"string","server_build":"string","server_uuid":"string","terrascan_desired":"boolean","terrascan_installed":"boolean","terrascan_version":"string","update":[{"href":"string","new_version":"boolean","restart":"boolean"}]}}}},"status":{"description":"Returns the server status.","method":"GET","uri":"server/status","response":{"codes":{"200":{"description":"Returns the server status (loading, ready, corrupt-db, feed-expired, eval-expired, locked, register, register-locked, download-failed, feed-error)."},"503":{"description":"Returns the server status. Indicates a session destroy is required."}},"sample":{"data":{"status":"string","progress":"integer"}}}},"restart":{"description":"Restarts the Nessus service and/or web server.","method":"POST","uri":"server/restart","request":{"parameters":{"payload":{"reason":{"type":"string","description":"Describes the reason that the service or web server is being restarted.","default":"user requested"},"soft":{"type":"boolean","description":"Indicates that only the web server should be restarted and not the service.","default":false},"unlink":{"type":"boolean","description":"Indicates whether the scanner should be unlinked from Tenable.io or Nessus Manager before restarting.","default":false},"when_idle":{"type":"boolean","description":"Indicates that the scanner should be restarted when there are no scans currently running.","default":false}}}},"response":{"codes":{"200":{"description":"Restart request was sent successfully."}}}}}},"session":{"name":"session","description":"","representations":[{"name":"session","description":"User session information.","parameters":{"id":{"type":"string","description":"The unique id of the user."},"username":{"type":"string","description":"The username for the user."},"email":{"type":"string","description":"The email address for the user."},"name":{"type":"string","description":"The full name for the user."},"type":{"type":"string","description":"The type of user."},"permissions":{"type":"integer","description":"The user role."},"lastlogin":{"type":"integer","description":"The last login for the user in unixtime."},"container_id":{"type":"integer","description":"The container id for the user."},"groups":{"type":"array","description":"The list of groups that the user belongs to."}}}],"methods":{"create":{"description":"Create a new session token for the given user. Certificate based logins require no parameters.","method":"POST","uri":"session","request":{"parameters":{"payload":{"username":{"type":"string","description":"The username for the person who is attempting to log in.","required":true},"password":{"type":"string","description":"The password for the person who is attempting to log in.","required":true,"masked":true}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns md5sum_wizard_templates, md5sum_tenable_links, and session token."},"400":{"description":"Returned if the username format is not valid."},"401":{"description":"Returned if the username or password is invalid."},"500":{"description":"Returned if too many users are connected."}},"sample":{"data":{"md5sum_wizard_templates":"string","token":"string","md5sum_tenable_links":"string"}}}},"destroy":{"description":"Logs the current user out and destroys the session.","method":"DELETE","uri":"session","request":{"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the session has been properly destroyed."},"401":{"description":"Returned if no session exists."}}}},"edit":{"description":"Changes settings for the current user.","method":"PUT","uri":"session","request":{"parameters":{"payload":{"name":{"type":"string","description":"Full name for the user."},"email":{"type":"string","description":"Email address for the user."}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the user session data."},"403":{"description":"Returned if the user does not have permission to edit the session data."},"500":{"description":"Returned if the server failed to edit the user."}}}},"get":{"description":"Returns the user session data.","method":"GET","uri":"session","request":{"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the user session data."},"403":{"description":"Returned if the user does not have permission to view the session data."}},"sample":{"data":"representation: session.session"}}},"password":{"description":"Changes password for the current user.","method":"PUT","uri":"session/chpasswd","request":{"parameters":{"payload":{"password":{"type":"string","description":"New password for the user.","required":true,"masked":true},"current_password":{"type":"string","description":"Current password for the user.","required":true,"masked":true}}},"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the user password has been changed."},"400":{"description":"Returned if the password is too short."},"403":{"description":"Returned if the user does not have permission to change the password."},"500":{"description":"Returned if the server failed to change the password."}}}},"keys":{"description":"Generates API Keys for the current user.","method":"PUT","uri":"session/keys","request":{"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returned if the user API Keys were generated."},"401":{"description":"Returned if the user is not logged in."}},"sample":{"data":{"accessKey":"string","secretKey":"string"}}}}}},"settings":{"name":"settings","description":"","representations":[{"name":"category","description":"A category of advanced settings.","parameters":{"name":{"type":"string","description":"The name of the category as displayed in the UI."},"order":{"type":"integer","description":"The order that this category appears in the UI."},"settings":{"type":"array","description":"A list of advanced settings that belong to this category.","children":["representation: settings.setting"]}}},{"name":"health_alert","description":"An individual alert generated by the scanner regarding its overall health.","parameters":{"alert":{"type":"string","description":"A short-form description of the scanner alert."},"description":{"type":"string","description":"The long-form description of the scanner alert, which may contain further details."},"severity":{"type":"integer","description":"The severity of the alert, whose values are the following:<ul style='margin-top: 8px'><li><b>1</b> - info</li><li><b>3</b> - warning</li><li><b>5</b> - critical</li></ul>"},"type":{"type":"string","description":"A category of alert types (for example, \"node-load\", \"system-specs\", etc.)."}}},{"name":"health_performance_statistic","description":"A timestamped record of the scanner's overall performance.","parameters":{"avg_dns_lookup_time":{"type":"integer","description":"The average amount of time (in milliseconds) it takes to perform a DNS lookup on detected hosts."},"avg_rdns_lookup_time":{"type":"integer","description":"The average amount of time (in milliseconds) it takes to perform a reverse DNS lookup on detected hosts."},"cpu_load_avg":{"type":"integer","description":"On Unix this is the \"load average\" provided by the operating system. On Windows this is the current CPU usage (see also \"nessus_cpu\")."},"kbytes_received":{"type":"integer","description":"The amount of data (in kilobytes) received by Nessus."},"kbytes_sent":{"type":"integer","description":"The amount of data (in kilobytes) sent by Nessus."},"nessus_cpu":{"type":"integer","description":"A normalized (0-100) value for the percentage of total system CPU available across all cores that is being used by Nessus."},"nessus_data_disk_free":{"type":"integer","description":"The amount of free disk space (in megabytes) for the configuration directory. By default this corresponds to the following directory:<ul style='margin-top: 8px'><li><b>Unix</b> - /opt/nessus/etc/nessus</li><li><b>Windows</b> - C:\\ProgramData\\Tenable\\Nessus\\conf</li><li><b>macOS</b> - /Library/Nessus/run/etc/nessus</ul>"},"nessus_data_disk_total":{"type":"integer","description":"The total disk size (in megabytes) for the configuration directory. By default this corresponds to the following directory:<ul style='margin-top: 8px'><li><b>Unix</b> - /opt/nessus/etc/nessus</li><li><b>Windows</b> - C:\\ProgramData\\Tenable\\Nessus\\conf</li><li><b>macOS</b> - /Library/Nessus/run/etc/nessus</ul>"},"nessus_log_disk_free":{"type":"integer","description":"The amount of free disk space (in megabytes) for the \"log\" directory. By default this corresponds to the following directory:<ul style='margin-top: 8px'><li><b>Unix</b> - /opt/nessus/var/nessus/logs</li><li><b>Windows</b> - C:\\ProgramData\\Tenable\\Nessus\\nessus\\logs</li><li><b>macOS</b> - /Library/Nessus/run/var/nessus/logs</li></ul>"},"nessus_log_disk_total":{"type":"integer","description":"The total disk size (in megabytes) for the \"log\" directory. By default this corresponds to the following directory:<ul style='margin-top: 8px'><li><b>Unix</b> - /opt/nessus/var/nessus/logs</li><li><b>Windows</b> - C:\\ProgramData\\Tenable\\Nessus\\nessus\\logs</li><li><b>macOS</b> - /Library/Nessus/run/var/nessus/logs</li></ul>"},"nessus_mem":{"type":"integer","description":"The total amount of real memory (in megabytes) currently in use by Nessus."},"nessus_vmem":{"type":"integer","description":"The total amount of virtual memory (in megabytes) currently in use by Nessus."},"num_dns_lookups":{"type":"integer","description":"The number of DNS lookups performed by Nessus."},"num_hosts":{"type":"integer","description":"The current number of hosts that are actively being scanned."},"num_rdns_lookups":{"type":"integer","description":"The number of reverse DNS lookups performed by Nessus."},"num_scans":{"type":"integer","description":"The number of actively running scans."},"num_tcp_sessions":{"type":"integer","description":"The number of open TCP connections at the time of this sampling."},"sys_cores":{"type":"integer","description":"The total number of CPU cores available on the device, as reported by the operating system."},"sys_ram":{"type":"integer","description":"The total amount of RAM available on the device, as reported by the operating system."},"temp_disk_free":{"type":"integer","description":"The amount of free disk space (in megabytes) for the system \"temp\" directory (%TEMP% or $TMPDIR or /tmp)."},"temp_disk_total":{"type":"integer","description":"The total disk size (in megabytes) for the system \"temp\" directory (%TEMP% or $TMPDIR or /tmp)."},"timestamp":{"type":"integer","description":"The time (in Unix time) when this scanner statistic sampling was generated."}}},{"name":"setting","description":"An advanced setting configuration object.","parameters":{"allow_custom":{"type":"boolean","description":"Indicates that the advanced setting can accept a custom value, in addition to the list of allowable values."},"allowable_values":{"type":"array","description":"A list of acceptable values.","children":[{"value":"any"}]},"backend_reload":{"type":"boolean","description":"Indicates that changing this advanced setting will require a restart of the Nessus web server for it to take effect."},"default":{"type":"any","description":"The default value of the advanced setting, if applicable."},"deprecated":{"type":"boolean","description":"Indicates if the advanced setting has been deprecated and should no longer be used."},"description":{"type":"string","description":"A description of the advanced setting."},"hide_if_not_set":{"type":"boolean","description":"Indicates that the advanced setting should be hidden from the UI, if there is no defined value."},"id":{"type":"string","description":"The unique identification value of this advanced setting."},"invalid_values":{"type":"array","description":"An array of literal values that are invalid for this advanced setting.","children":[]},"max":{"type":"integer","description":"The maximum allowable value of an \"integer\" type advanced setting."},"min":{"type":"integer","description":"The minimum allowable value of an \"integer\" type advanced setting."},"name":{"type":"string","description":"The name of the advanced setting, as it appears in the UI."},"regex":{"type":"string","description":"A regular expression that is used to validate a change to the advanced setting's value."},"service_restart":{"type":"boolean","description":"Indicates that changing this advanced setting will require a restart of the Nessus service for it to take effect."},"setting":{"type":"string","description":"The name of the advanced setting as identified by the backend."},"type":{"type":"string","description":"Defines the control type of the advanced setting in the UI.  The absence of this value means it will use a text box. The supported types are as follows:<ul style='margin-top: 8px'><li><b>boolean</b> - a drop-down box where the user can choose either \"yes\" or \"no\"</li><li><b>integer</b> - a text box that only accepts numeric values</li><b>select</b> - a drop-down box that lists allowable values</li><li><b>string</b> - a text box</li></ul>"},"value":{"type":"any","description":"The value of an advanced setting. Sometimes it can be omitted in place of its \"default\" value."}}}],"methods":{"health-alert-list":{"description":"A list of alerts created by the scanner regarding its overall health.","method":"GET","uri":"settings/health/alerts","request":{"parameters":{"query":{"end_time":{"type":"integer","description":"End time for historical data (in unixtime); defaults to now.","required":false},"start_time":{"type":"integer","description":"Start time for historical data (in unixtime); defaults to 24 hours ago.","required":false}}}},"response":{"codes":{"200":{"description":"The scanner alerts list was retrieved successfully."}},"sample":{"data":["representation: settings.health_alert"]}}},"health-stats":{"description":"A historical record of scanner statistics based on metrics such as memory usage, data sent/received, etc.","method":"GET","uri":"settings/health/stats","request":{"parameters":{"query":{"end_time":{"type":"integer","description":"End time for historical data (in unixtime); defaults to now.","required":false},"start_time":{"type":"integer","description":"Start time for historical data (in unixtime); defaults to 24 hours ago.","required":false},"count":{"type":"integer","description":"Maximum number of data points to be reported back; defaults to 24.","required":false}}}},"response":{"codes":{"200":{"description":"The scanner stats were retrieved successfully."}},"sample":{"data":{"perf_stats_current":"representation: settings.health_performance_statistic","perf_stats_history":["representation: settings.health_performance_statistic"]}}}},"list-advanced":{"description":"Lists the advanced settings, its configurations, and its current values.","method":"GET","uri":"settings/advanced","request":{"permissions":{"type":"user","value":"64"},"warning":"This documentation is based on <b>version 3</b> of this method. To use this version, you will need to include the following header in your requests: <b>X-API-Version: 3.0</b>"},"response":{"codes":{"200":{"description":"Returned if the list of advanced settings were retrieved successfully"}},"sample":{"data":{"restart_status":"boolean","running_scans_count":"integer","settings":{"{Category Name}":"representation: settings.category"}}}}},"modify-advanced":{"description":"A CRUD interface for adding, editing, and deleting custom advanced settings.  In addition, users can edit or reset Tenable-provided advanced settings.","method":"PUT","uri":"settings/advanced","request":{"parameters":{"payload":{"setting.0.action":{"type":"string","description":"This describes the action to be performed on the advanced setting.  It must be one of the following values:<ul style='margin-top: 8px'><li><b>add</b> - used for creating a custom advanced setting</li><li><b>edit</b> - used for editing an existing setting</li><li><b>remove</b> - used for removing a custom advanced setting or resetting a Tenable-provided advanced setting</li></ul>","required":true},"setting.0.id":{"type":"string","description":"A unique identification value of the advanced setting being operated on.   It's only necessary when editing or removing a custom advanced setting or when editing or resetting a Tenable-provided advanced setting.","required":false},"setting.0.name":{"type":"string","description":"The name of the advanced setting being acted upon as identified by the backend.","required":true},"setting.0.value":{"type":"string","description":"The value that the advanced setting is being set to.","required":false}}},"permissions":{"type":"user","value":"64"}},"response":{"codes":{"200":{"description":"Returned if all the actions to the advanced settings were completed successfully."},"400":{"description":"Returned if one of the following happens:<ol style='margin-top: 8px'><li><b>(1)</b> when adding the advanced setting, another advanced setting with that name already exists.</li><li><b>(2)</b> the value submitted for that advanced setting was invalid.</li></ol>"},"500":{"description":"Returned if it could not retrieve the list of advanced settings."}},"sample":{"data":{"new":[{"category":null,"id":"string","name":"string"}]}}}},"modify-plugin-detail-locale":{"description":"The locale (language) in which plugin details appear in the Tenable Nessus user interface and reports.","method":"PUT","uri":"settings/plugin-detail-locale","request":{"parameters":{"payload":{"enabled":{"type":"boolean","description":"Enables or disables plugin detail locales.","required":false},"default_plugin_locale":{"type":"string","description":"The default locale in which plugin details appear.","required":false},"current":{"type":"list","description":"The list of locale packs to download.","required":false}}},"permissions":{"type":"user","value":"64"}},"response":{"codes":{"200":{"description":"Returned if settings were saved successfully."}}}},"get-plugin-detail-locale":{"description":"Locale plugin details.","method":"GET","uri":"settings/plugin-detail-locale","request":{"permissions":{"type":"user","value":"64"},"warning":"This documentation is based on <b>version 3</b> of this method. To use this version, you will need to include the following header in your requests: <b>X-API-Version: 3.0</b>"},"response":{"codes":{"200":{"description":"Returned if the locale settings were retrieved successfully."}},"sample":{"data":{"current":{"zh_CN":{"display":"Chinese Simplified","selected":false},"ja":{"md5":"d3b07384d113edec49eaa6238ad5ff00","display":"Japanese","selected":true},"zh_TW":{"display":"Chinese Traditional","selected":false}},"enabled":true,"locale":"ja","allowable_values":{"description":"Locale in which to display plugin metadata","setting":"plugin_detail_locale","allowable_values":[{"display":"English","value":"en"},{"display":"Japanese","value":"ja"},{"display":"Chinese (Traditional)","value":"zh_TW"},{"display":"Chinese (Simplified)","value":"zh_CN"}],"id":"c8f4acfc51005906b16e37a90ba059fa","type":"select","hidden":true,"default":"en","categoryKey":"Misc","name":"Plugin Detail Locale","category":"Miscellaneous"}}}}}}},"software-update":{"name":"software-update","description":"","methods":{"schedule":{"description":"Schedules a software update for all components.","method":"POST","uri":"settings/software-update","request":{"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the software update was scheduled successfully."},"403":{"description":"Returned if the user does not have permission to schedule software updates."}}}},"settings":{"description":"Changes the software update settings","method":"PUT","uri":"settings/software-update","request":{"parameters":{"payload":{"update":{"type":"string","description":"The components to update (all, plugins, or disabled).","required":true,"dropdown":true,"options":["all","plugins","disabled"]},"custom_host":{"type":"string","description":"The URL for a custom plugin feed host."},"auto_update_delay":{"type":"int","description":"How often the plugin feed attempts to update (in hours)."}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the software update settings were changed successfully."},"403":{"description":"Returned if the user does not have permission to change the software update settings."}}}}}},"terrascan":{"name":"terrascan","description":"","manager_not_supported":true,"representations":[{"name":"terrascan","description":"Terrascan information","parameters":{"installed":{"type":"boolean","description":"Whether Terrascan is installed or not."},"path":{"type":"string","description":"The location on disk where Terrascan is installed."},"status":{"type":"string","description":"Status of Terrascan."},"terrascan":{"type":"boolean","description":"Boolean. Set to true if Terrascan should be installed, otherwise set to false."},"version":{"type":"string","description":"Terrascan version installed."}}}],"methods":{"get-info":{"description":"Returns information about Terrascan","method":"GET","uri":"tools/terrascan","expert_only":true,"response":{"codes":{"200":{"description":"Returns information about the Terrascan install."}},"sample":{"data":{"installed":"boolean","path":"string","status":"string","terrascan_desired":"boolean","version":"string"}}}},"set-desired":{"description":"Set whether to install or remove Terrascan.","method":"POST","uri":"tools/terrascan","expert_only":true,"request":{"parameters":{"payload":{"terrascan":{"type":"boolean","description":"Boolean. Set to true if Terrascan should be installed, otherwise set to false.","required":true}}}},"response":{"codes":{"200":{"description":"Returned if the variable was set successfully."}}}},"download":{"description":"Download Terrascan","method":"POST","uri":"tools/terrascan/download","expert_only":true,"response":{"codes":{"200":{"description":"Returned if the call was successful."}}}},"get-config":{"description":"Get configuration","method":"GET","uri":"tools/terrascan/configs/{config_id}","expert_only":true,"request":{"parameters":{"path":{"config_id":{"type":"integer","description":"Configuration ID","required":true}}}},"response":{"codes":{"200":{"description":"Returns a configuration."}}}},"save-config":{"description":"Save a configuration","method":"POST","uri":"tools/terrascan/configs","expert_only":true,"request":{"parameters":{"payload":{"config":{"type":"json","description":"Configuration","required":true},"name":{"type":"string","description":"Configuration name","required":true},"config_id":{"type":"integer","description":"Configuration ID","required":false}}}},"response":{"codes":{"200":{"description":"Returned if the configuration was saved successfully."}}}},"delete-config":{"description":"Delete configuration","method":"DELETE","uri":"tools/terrascan/configs/{config_id}","expert_only":true,"response":{"codes":{"200":{"description":"Returned if the configuration was successfully deleted."}}}},"edit-config":{"description":"Saves configuration","method":"PUT","uri":"tools/terrascan/configs/{config_id}","expert_only":true,"request":{"parameters":{"payload":{"config_id":{"type":"integer","description":"Configuration ID.","required":true}}}},"response":{"codes":{"200":{"description":"Returned if the configuration was changed."}}}},"get-configs":{"description":"List of configurations","method":"GET","uri":"tools/terrascan/configs","expert_only":true,"response":{"codes":{"200":{"description":"Returns the list of configurations."}}}},"delete-configs":{"description":"Delete configurations","method":"DELETE","uri":"tools/terrascan/configs","expert_only":true,"request":{"parameters":{"payload":{"config_id":{"type":"integer","description":"Configuration to delete","required":true}}}},"response":{"codes":{"200":{"description":"Returned if the specified configurations were deleted successfully."}}}},"get-default-config":{"description":"Get default configuration","method":"GET","uri":"tools/terrascan/configs/default","expert_only":true,"response":{"codes":{"200":{"description":"Returns the defaults for a configuration."}}}},"get-scans":{"description":"List of Terrascan scans","method":"GET","uri":"tools/terrascan/scans/{config_id}","expert_only":true,"request":{"parameters":{"path":{"config_id":{"type":"integer","description":"Configuration ID","required":true}},"query":{"scan_id":{"type":"integer","description":"The id of the scan to retrieve.","required":false}}}},"response":{"codes":{"200":{"description":"Returns a list of scans for the configuration ID."}}}},"launch-scan":{"description":"Launch Terrascan scan","method":"POST","uri":"tools/terrascan/scans/{config_id}","expert_only":true,"request":{"parameters":{"payload":{"config_id":{"type":"integer","description":"Configuration ID","required":true}}}},"response":{"codes":{"200":{"description":"Returned if the Scan is started successfully."},"400":{"description":"Returned if no format was specified."},"404":{"description":"Returned if no scan configuration data is found for the config_id or if the Terrascan executable is not found."}}}},"delete-scan":{"description":"Delete Terrascan Scan","method":"DELETE","uri":"tools/terrascan/scan","expert_only":true,"request":{"parameters":{"payload":{"scan_ids":{"type":"array","description":"List of scan ids","required":true}}}},"response":{"codes":{"200":{"description":"Returned if the scans are deleted successfully."}}}},"download-scan-result":{"description":"Download Terrascan scan results","method":"GET","uri":"tools/terrascan/scan/results/{config_id}/{scan_id}/{format}","expert_only":true,"request":{"parameters":{"path":{"config_id":{"type":"integer","description":"Configuration ID","required":true},"scan_id":{"type":"integer","description":"Scan ID","required":true},"format":{"type":"string","description":"desired format","required":true}}}},"response":{"codes":{"200":{"description":"Returns results."}}}},"download-scan-result-command-output":{"description":"Download Terrascan scan result command output","method":"GET","uri":"tools/terrascan/scan/command_output/{config_id}/{scan_id}","expert_only":true,"request":{"parameters":{"path":{"config_id":{"type":"integer","description":"Configuration ID","required":true},"scan_id":{"type":"integer","description":"Scan ID","required":true}}}},"response":{"codes":{"200":{"description":"Returns the command output from a given scan."}}}}}},"tokens":{"name":"tokens","description":"","representations":[{"name":"token","description":"The details of a token.","parameters":{"token":{"type":"string","description":"The unique token string."}}}],"methods":{"status":{"description":"Gets the status of a token; used for token based downloads.","method":"GET","uri":"tokens/{token}/status","request":{"parameters":{"path":{"token":{"type":"string","description":"The token string.","required":true}}}},"response":{"codes":{"200":{"description":"Returns the token status and message."},"404":{"description":"Returned if the given token does not exist or expired."}},"sample":{"data":{"status":"string","message":"string"}}}},"download":{"description":"Downloads the payload for the given token.","method":"GET","uri":"tokens/{token}/download","request":{"parameters":{"path":{"token":{"type":"string","description":"The token string.","required":true}}}},"response":{"codes":{"200":{"description":"The token's payload will be returned as a file."},"404":{"description":"Returned if the given token does not exist or expired."}}}}}},"users":{"name":"users","description":"","representations":[{"name":"user","description":"Users can access features based on their given role.","parameters":{"id":{"type":"integer","description":"The unique id of the user."},"username":{"type":"string","description":"The username for the user."},"name":{"type":"string","description":"The real name of the user."},"email":{"type":"string","description":"The email address for the user."},"permissions":{"type":"integer","description":"The role of the user as described <a href=\"#/authorization\">here</a>."},"lastlogin":{"type":"integer","description":"The last login for the user in unixtime."},"type":{"type":"string","description":"The type of user (local or ldap)."},"login_fail_count":{"type":"integer","description":"The number of failed login attempts for the user since the last successful login."},"login_fail_total":{"type":"integer","description":"The total number of failed login attempts for the user."},"last_login_attempt":{"type":"integer","description":"The timestamp of the last failed login attempt for the user."}}}],"methods":{"create":{"description":"Create a new user.","method":"POST","uri":"users","manager_only":true,"request":{"parameters":{"payload":{"username":{"type":"string","description":"The username for the user.","required":true},"password":{"type":"string","description":"The initial password for the user.","required":true,"masked":true},"permissions":{"type":"string","description":"The role of the user.","required":true,"dropdown":true,"options":["16","32","64"]},"name":{"type":"string","description":"The real name of the user."},"email":{"type":"string","description":"The email address of the user."},"type":{"type":"string","description":"The type of user.","dropdown":true,"options":["local"],"required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the user object."},"400":{"description":"Returned if a field is invalid."},"403":{"description":"Returned if the user does not have permission to create a user."},"409":{"description":"Returned if duplicate user."}},"sample":{"data":"representation: users.user"}}},"delete":{"description":"Delete a user.","method":"DELETE","uri":"users/{user_id}","request":{"parameters":{"path":{"user_id":{"type":"integer","description":"The unique id of the user.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the server deleted the user."},"403":{"description":"Returned if the user does not have permission to delete the user."},"404":{"description":"Returned if the user does not exist."},"409":{"description":"Returned if the user tried to delete his own account."},"500":{"description":"Returned if the server failed to delete the user."}}}},"delete-bulk":{"description":"Delete users in bulk.","method":"DELETE","uri":"users","request":{"parameters":{"payload":{"ids":{"type":"array","description":"Array of user IDs to delete.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the users have been successfully deleted."},"400":{"description":"Returned if any of the user IDs are invalid."},"403":{"description":"Returned if the user does not have permission to delete user."},"409":{"description":"Returned if duplicate user."},"500":{"description":"Returned if the server failed to delete the users."}},"sample":{"data":{"deleted":"array"}}}},"details":{"description":"Returns details for the given user.","method":"GET","uri":"users/{user_id}","request":{"parameters":{"path":{"user_id":{"type":"integer","description":"The unique id of the user.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the user object."},"403":{"description":"Returned if the user does not have permission to view the given user details."},"404":{"description":"Returned if the user does not exist."}},"sample":{"data":"representation: users.user"}}},"edit":{"description":"Edits an existing user.","method":"PUT","uri":"users/{user_id}","request":{"parameters":{"path":{"user_id":{"type":"integer","description":"The unique id of the user.","required":true}},"payload":{"permissions":{"type":"string","description":"The role of the user.","required":true,"dropdown":true,"options":["16","32","64"]},"name":{"type":"string","description":"The real name of the user."},"email":{"type":"string","description":"The email address of the user."}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returns the user object."},"400":{"description":"Returned if a field is invalid."},"403":{"description":"Returned if the user does not have permission to edit a user."},"404":{"description":"Returned if the user does not exist."}},"sample":{"data":"representation: users.user"}}},"list":{"description":"Returns the user list.","method":"GET","uri":"users","request":{"permissions":{"type":"user","value":16}},"response":{"codes":{"200":{"description":"Returns the user list."},"403":{"description":"Returned if the user does not have permission to view the list."}},"sample":{"data":{"users":["representation: users.user"]}}}},"password":{"description":"Changes the password for the given user.","method":"PUT","uri":"users/{user_id}/chpasswd","request":{"parameters":{"path":{"user_id":{"type":"integer","description":"The unique id of the user.","required":true}},"payload":{"current_password":{"type":"string","description":"Current password for the user.","required":true,"masked":true},"password":{"type":"string","description":"New password for the user.","required":true,"masked":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the user password has been changed."},"400":{"description":"Returned if the password is too short."},"403":{"description":"Returned if the user does not have permission to change the user's password."},"404":{"description":"Returned if the user does not exist."},"500":{"description":"Returned if the server failed to change the password."}}}},"keys":{"description":"Generates the API Keys for the given user.","method":"PUT","uri":"users/{user_id}/keys","request":{"parameters":{"path":{"user_id":{"type":"integer","description":"The unique id of the user.","required":true}}},"permissions":{"type":"user","value":64}},"response":{"codes":{"200":{"description":"Returned if the user API Keys were generated."},"403":{"description":"Returned if the user does not have permission to generate API keys."},"404":{"description":"Returned if the user does not exist."},"500":{"description":"Returned if the server failed to change the keys."}},"sample":{"data":{"accessKey":"string","secretKey":"string"}}}}}}}}